<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="exchangeRateGainsCommon.xslt"/>
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="showCustomerSupplierFields"><xsl:value-of select="@showCustomerSupplierFields"/></xsl:variable>
        <xsl:variable name="showContainerField"><xsl:value-of select="@showContainerField"/></xsl:variable>
        <xsl:variable name="showNilAccounts" select="@showNilAccounts"/>
        <xsl:variable name="reportTitle2"><xsl:value-of select="@categoryName"/></xsl:variable>
        <xsl:variable name="reportTitle1">***AccountsByCategory***</xsl:variable>
        
        <xsl:variable name="reportTitleFull">
            <xsl:value-of select="$reportTitle1"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="$reportTitle2"/>
        </xsl:variable>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportTitle1"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle">
                            <xsl:value-of select="$reportTitle1"/>
                            <xsl:text> ***for*** </xsl:text>
                            <xsl:value-of select="@businessName"/>
                        </h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>.
                        </h2>
                        <xsl:call-template name="messages"/>

                        <xsl:if test="number(@selectionCount) = 0">
                            <p>***PleaseSelectACategory.***</p>
                        </xsl:if>
                        
                        <xsl:if test="number(@selectionCount) &gt; 0">
                            <h2 style="{$h2Style}">
                                <xsl:value-of select="$reportTitle2"/>
                            </h2>
                            
                            <table id="mainTable" class="paddedTable" title="{$reportTitleFull}" style="{$tableStyle}">
                                <tbody>
                                    <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                        <th></th>
                                        <xsl:if test="$showContainerField = '1'">
                                            <th></th>
                                        </xsl:if>
                                        <th></th>
                                        <th colspan="5" style="{$headingsLineStyle} {$center}">
                                            ***AccountCurrency***
                                        </th>
                                        <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                            <th colspan="2" style="{$headingsLineStyle} {$center}">
                                                ***BusinessCurrency***  (<xsl:value-of select="/*/currencies/row[@uidCurrency = 0]/@code"/>)
                                            </th>
                                        </xsl:if>
                                        <xsl:if test="$showCustomerSupplierFields = '1'">
                                            <th colspan="6"></th>
                                        </xsl:if>
                                        <th></th>
                                    </xsl:if>
                                    <tr >
                                        <th style="{$headingsLineStyle} {$left}">
                                            ***Category***
                                        </th>
                                        <xsl:if test="$showContainerField = '1'">
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***ParentAccount***
                                            </th>
                                        </xsl:if>
                                        <th style="{$headingsLineStyle} {$left}">
                                            ***Account***
                                        </th>
                                        <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***Currency***
                                            </th>
                                        </xsl:if>
                                        <th style="{$headingsLineStyle} {$left}">
                                            ***B/F***
                                        </th>
                                        <th style="{$headingsLineStyle} {$right}">
                                            <xsl:value-of select="@debitText"/>
                                        </th>
                                        <th style="{$headingsLineStyle} {$right}">
                                            <xsl:value-of select="@creditText"/>
                                        </th>
                                        <th style="{$headingsLineStyle} {$right}">
                                            <xsl:value-of select="@balanceText"/>
                                        </th>
                                        <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                            <th style="{$headingsLineStyle} {$right}">
                                                ***GainsLosses***
                                            </th>
                                            <th style="{$headingsLineStyle} {$right}">
                                                ***Balance***
                                            </th>
                                        </xsl:if>
                                        <xsl:if test="$showCustomerSupplierFields = '1'">
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***AccountRef***
                                            </th>
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***EmailAddress***
                                            </th>
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***InvoiceAddress***
                                            </th>
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***DeliveryAddress***
                                            </th>
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***PaymentTerms***
                                            </th>
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***EstimateTerms***
                                            </th>
                                        </xsl:if>
                                        <th style="{$headingsLineStyle} {$right}">
                                            ***Notes***
                                        </th>
                                    </tr>
                                    
                                    <xsl:for-each select="accounts/row[$showNilAccounts='Y' or
                                        not(number(@totalCurrBF)=0 and number(@totalCurrP)=0 and number(@totalCurrN)=0 and number(@totalCurr)=0)]">
                                        
                                        <xsl:variable name="uidCurrency" select="@uidCurrency"/>
                                        <xsl:variable name="currency" select="/*/currencies/row[@uidCurrency = $uidCurrency]"/>
                                        
                                        <tr class="accountRow" uidAccount="{@uidAccount}">
                                            <td style="{$firstColumnStyle} {$DrCrL}" >
                                                <xsl:value-of select="@subCatDesc"/>
                                            </td>
                                            <xsl:if test="$showContainerField = '1'">
                                                <td><xsl:value-of select="@parentAccountName"/></td>
                                            </xsl:if>
                                            <td style="{$DrCrR}"><xsl:value-of select="@accountName"/></td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td><xsl:value-of select="$currency/@code"/></td>
                                            </xsl:if>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCurrBF * @scaleBalance"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCurrP"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCurrN"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$DrCrR} {$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCurr * @scaleBalance"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td style="{$money}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@total_gain"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$DrCrR} {$money}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@total * @scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                            </xsl:if>
                                            
                                            <xsl:if test="$showCustomerSupplierFields = '1'">
                                                <td><xsl:value-of select="@ACCOUNT-REF"/></td>
                                                <td><xsl:value-of select="@EMAIL-ADDR"/></td>
                                                <td style="{$preformatted}" ><xsl:value-of select="@INVOICE-TO"/></td>
                                                <td style="{$preformatted}" ><xsl:value-of select="@DELIVER-TO"/></td>
                                                <td style="{$preformatted}" ><xsl:value-of select="@TERMS"/></td>
                                                <td style="{$preformatted}" ><xsl:value-of select="@ESTIMATE-TERMS"/></td>
                                            </xsl:if>
                                            <td style="{$preformatted} {$DrCrR}" ><xsl:value-of select="@NOTES"/></td>
                                            
                                        </tr>
                                        
                                    </xsl:for-each>
                                    
                                    <tr >
                                        <td style="{$firstColumnStyle} {$DrCrL} {$bottomBorder}">
                                            &#160;
                                        </td>
                                        <xsl:if test="$showContainerField = '1'">
                                            <td style="{$bottomBorder}"></td>
                                        </xsl:if>
                                        <td style="{$DrCrR} {$bottomBorder}"></td>
                                        <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                            <td style="{$bottomBorder}"></td>
                                        </xsl:if>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$DrCrR} {$bottomBorder}"></td>
                                        <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$DrCrR} {$bottomBorder}"></td>
                                        </xsl:if>
                                        <xsl:if test="$showCustomerSupplierFields = '1'">
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                        </xsl:if>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            &#160;
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            
                        </xsl:if>

                    </div>
                </div>

                <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                    <br />
                    <xsl:call-template name="exchangeRates"/>
                </xsl:if>

                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
</xsl:transform>
