<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***Audit Report***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle">***Audit Report*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>
                        </h2>
                        <div style="{$h3Style}">***Prepared on***
                            <xsl:value-of select="@runTime"/>
                        </div>
                        <xsl:call-template name="messages"/>
                        
                        <div>
                            <table id="mainTable" class="paddedTable" title="Audit Report" style="{$tableStyle}">
                                <colgroup>
                                    <col style="{$DrCrL}"/>
                                    <col />
                                    <col />
                                    <col />
                                    <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                        <col style="{$DrCrL}"/>
                                        <col style="{$DrCrR}"/>
                                    </xsl:if>
                                    <col style="{$DrCrL}"/>
                                    <col style="{$DrCrR}"/>
                                    <col style="{$DrCrR}"/>
                                </colgroup>
                                <tbody>
                                    <tr>
                                        <th style="{$headingsLineStyle} {$left}">Date</th>
                                        <th style="{$headingsLineStyle} {$left}">Description</th>
                                        <th style="{$headingsLineStyle} {$left}">Detail</th>
                                        <th style="{$headingsLineStyle} {$left}">Account</th>
                                        <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                            <th style="{$headingsLineStyle} {$right}">Dr</th>
                                            <th style="{$headingsLineStyle} {$right}">Cr</th>
                                        </xsl:if>
                                        <th style="{$headingsLineStyle} {$right}">Dr</th>
                                        <th style="{$headingsLineStyle} {$right}">Cr</th>
                                        <th style="{$headingsLineStyle} {$right}">ID</th>
                                    </tr>
                                    
                                    <xsl:variable name="rows" select="accounts/row[transactions/row or not(@total=0)][@isContainer='0']"/>
                                    
                                    <xsl:for-each select="$rows">
                                        <xsl:variable name="uidAccount" select="@uidAccount"/>
                                        <xsl:variable name="addVatToBalance" select="@addVatToBalance"/>
                                        <xsl:variable name="totalBF" select="@total"/>
                                        <xsl:variable name="totalCF" select="@totalCF"/>
                                        <xsl:variable name="totalCurrBF" select="@totalCurr"/>
                                        <xsl:variable name="totalCurrCF" select="@totalCurrCF"/>
                                        <xsl:variable name="uidCurrency" select="@uidCurrency"/>
                                        <xsl:variable name="currency" select="/*/currencies/row[@uidCurrency = $uidCurrency]"/>
                                        
                                        <tr class="accountRow" uidAccount="{@uidAccount}">
                                            <td colspan="4">
                                                <h1 style="{$h2Style}"><xsl:value-of select="@accountName"/></h1>
                                            </td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td colspan="2"></td>
                                            </xsl:if>
                                            <td colspan="2"></td>
                                            <td></td>
                                        </tr>
                                        <tr>
                                            <td colspan="4">
                                                <h3 style="{$h3Style}">(<xsl:value-of select="@catDesc"/> / <xsl:value-of select="@subCatDesc"/>)</h3>
                                            </td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td style="{$right}">
                                                    <xsl:if test="$totalBF &gt;= 0 and not($uidCurrency = 0)">
                                                        <xsl:value-of select="$currency/@code"/>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$right}">
                                                    <xsl:if test="$totalBF &lt; 0 and not($uidCurrency = 0)">
                                                        <xsl:value-of select="$currency/@code"/>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$right}">
                                                    <xsl:if test="$totalBF &gt;= 0">
                                                        <xsl:value-of select="/*/currencies/row[@uidCurrency='0']/@code"/>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$right}">
                                                    <xsl:if test="$totalBF &lt; 0">
                                                        <xsl:value-of select="/*/currencies/row[@uidCurrency='0']/@code"/>
                                                    </xsl:if>
                                                </td>
                                            </xsl:if>
                                            <xsl:if test="/*/@foreignCurrencyCount = 0">
                                                <td colspan="2"></td>
                                            </xsl:if>
                                            <td></td>
                                        </tr>
                                        <tr>
                                            <td colspan="4">***B/F***</td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td style="{$money}" >
                                                    <xsl:if test="$totalBF &gt;= 0 and not($uidCurrency = 0)">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$totalCurrBF"/>
                                                            <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money}" >
                                                    <xsl:if test="$totalBF &lt; 0 and not($uidCurrency = 0)">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="-1 * $totalCurrBF"/>
                                                            <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                            </xsl:if>
                                            <td style="{$money}" >
                                                <xsl:if test="$totalBF &gt;= 0">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$totalBF"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:if test="$totalBF &lt; 0">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="-1 * $totalBF"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td></td>
                                        </tr>
                                        
                                        <xsl:for-each select="transactions/row">
                                            <xsl:variable name="uidAccountVat" select="@uidAccountVat"/>
                                            <xsl:variable name="amount">
                                                <xsl:choose>
                                                    <xsl:when test="$uidAccount = $uidAccountVat">
                                                        <xsl:value-of select="@vatAmount"/>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="@amount"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:variable>
                                            <xsl:variable name="amountCurr">
                                                <xsl:choose>
                                                    <xsl:when test="$uidAccount = $uidAccountVat">
                                                        <xsl:value-of select="@vatAmountCurr"/>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="@amountCurr"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:variable>
                                            
                                            <tr class="transactionRow" uidJournal="{@uidJournal}">
                                                <td style="white-space:nowrap;">
                                                    <xsl:value-of select="@_postingDate"/>
                                                </td>
                                                <td><xsl:value-of select="@whatForText"/></td>
                                                <td><xsl:value-of select="@detail"/></td>
                                                <td><xsl:value-of select="@account2Name"/></td>
                                                <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                    <td style="{$money}" >
                                                        <xsl:if test="$amountCurr &gt;= 0 and not($uidCurrency = 0)">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="$amountCurr"/>
                                                                <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:if test="$amountCurr &lt; 0 and not($uidCurrency = 0)">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="-1 * $amountCurr"/>
                                                                <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                </xsl:if>
                                                <td style="{$money}" >
                                                    <xsl:if test="$amount &gt;= 0">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$amount"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money}" >
                                                    <xsl:if test="$amount &lt; 0">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="-1 * $amount"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td><xsl:value-of select="@uidJournal"/></td>
                                            </tr>
                                            
                                            <xsl:if test="$addVatToBalance = '1' and not(@vatAmount = '0')">
                                                <tr class="transactionRow" uidJournal="{@uidJournal}">
                                                    <td colspan="3"></td>
                                                    <td><xsl:value-of select="@account3Name"/></td>
                                                    <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                        <td style="padding:5px 10px;{$right}" >
                                                            <xsl:if test="@vatAmountCurr &gt;= 0 and not($uidCurrency = 0)">
                                                                <xsl:call-template name="formatCurrency">
                                                                    <xsl:with-param name="pence" select="@vatAmountCurr"/>
                                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                                </xsl:call-template>
                                                            </xsl:if>
                                                        </td>
                                                        <td style="padding:5px 10px;{$right}" >
                                                            <xsl:if test="@vatAmountCurr &lt; 0 and not($uidCurrency = 0)">
                                                                <xsl:call-template name="formatCurrency">
                                                                    <xsl:with-param name="pence" select="-1 * @vatAmountCurr"/>
                                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                                </xsl:call-template>
                                                            </xsl:if>
                                                        </td>
                                                    </xsl:if>
                                                    <td style="padding:5px 10px;{$right}" >
                                                        <xsl:if test="@vatAmount &gt;= 0">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="@vatAmount"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                    <td style="padding:5px 10px;{$right}" >
                                                        <xsl:if test="@vatAmount &lt; 0">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="-1 * @vatAmount"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                    <td><xsl:value-of select="@uidJournal"/></td>
                                                </tr>
                                            </xsl:if>
                                        </xsl:for-each>
                                        
                                        <tr>
                                            <td colspan="4">***C/F***</td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td style="{$money} {$bold}" >
                                                    <xsl:if test="$totalCurrCF &gt;= 0 and not($uidCurrency = 0)">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$totalCurrCF"/>
                                                            <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money} {$bold}" >
                                                    <xsl:if test="$totalCurrCF &lt; 0 and not($uidCurrency = 0)">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="-1 * $totalCurrCF"/>
                                                            <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                            </xsl:if>
                                            <td style="{$money} {$bold}" >
                                                <xsl:if test="$totalCF &gt;= 0">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$totalCF"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$bold}" >
                                                <xsl:if test="$totalCF &lt; 0">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="-1 * $totalCF"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td></td>
                                        </tr>
                                        
                                        <tr>
                                            <td colspan="4" style="{$bottomBorder}">&#160;</td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td colspan="2" style="{$bottomBorder}"></td>
                                            </xsl:if>
                                            <td colspan="2" style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                        </tr>
                                        
                                    </xsl:for-each>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
</xsl:transform>
