<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="exchangeRateGainsCommon.xslt"/>
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>

    <xsl:template match="/root">
        
        <xsl:variable name="showVat" select="@showVat"/>
        <xsl:variable name="reportTitle">
            <xsl:choose>
                <xsl:when test="@report = 'CUSTOMER'">
                    <xsl:text>***Best Customers***</xsl:text>
                </xsl:when>
                <xsl:when test="@report = 'SUPPLIER'">
                    <xsl:text>***Top Suppliers***</xsl:text>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>

        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportTitle"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle"><xsl:value-of select="$reportTitle"/></h1>
                        <h2 style="{$h2Style}">***From***
                            <xsl:value-of select="@fromDate"/>
                            ***to***
                            <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        <br />
                        
                        <xsl:variable name="rowsNonZero" select="accounts/row[not(number(@total)=0 and number(@totalbf)=0 and number(@totalcf)= 0)]"/>
                        
                        <table id="mainTable" title="{$reportTitle}" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th style="{$headingsLineStyle} {$left}">
                                        <xsl:choose>
                                            <xsl:when test="@report = 'CUSTOMER'">
                                                <xsl:text>***Customer***</xsl:text>
                                            </xsl:when>
                                            <xsl:when test="@report = 'SUPPLIER'">
                                                <xsl:text>***Supplier***</xsl:text>
                                            </xsl:when>
                                        </xsl:choose>
                                    </th>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***B/F***
                                    </th>
                                    <th style="{$headingsLineStyle} {$right}">
                                        <xsl:choose>
                                            <xsl:when test="@report = 'CUSTOMER'">
                                                <xsl:text>***Sales***</xsl:text>
                                            </xsl:when>
                                            <xsl:when test="@report = 'SUPPLIER'">
                                                <xsl:text>***Purchases***</xsl:text>
                                            </xsl:when>
                                        </xsl:choose>
                                    </th>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***Credits***
                                    </th>
                                    <xsl:if test="$showVat">
                                        <th style="{$headingsLineStyle} {$right}">
                                            ***VAT***
                                        </th>
                                    </xsl:if>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***Total***
                                    </th>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***Payments***
                                    </th>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***Refunds***
                                    </th>
                                    <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                        <th style="{$headingsLineStyle} {$right}">
                                            ***GainsLosses***
                                        </th>
                                    </xsl:if>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***C/F***
                                    </th>
                                </tr>
                                
                                <xsl:for-each select="currencies/row">
                                    <xsl:variable name="uidCurrency" select="@uidCurrency"/>
                                    <xsl:variable name="row" select="$rowsNonZero[@uidCurrency=$uidCurrency]"/>
                                
                                    <xsl:if test="$row and /*/@foreignCurrencyCount &gt; 0">
                                        <tr>
                                            <td colspan="4" style="{$firstColumnStyle} {$DrCrL} {$catName}" >
                                                <xsl:value-of select="@name"/>
                                            </td>
                                            <xsl:if test="$showVat">
                                                <td></td>
                                            </xsl:if>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td></td>
                                            </xsl:if>
                                            <td colspan="4" style="{$DrCrR}" >
                                            </td>
                                        </tr>
                                    </xsl:if>
                                
                                    <xsl:for-each select="$row">
                                        <xsl:sort order="descending" data-type="number" select="@totalInvoice"/>
                                        <tr class="accountRow" uidAccount="{@uidAccount}" uidSubCat="{@uidAccountSubCat}">
                                            <td style="{$firstColumnStyle} {$DrCrL}" >
                                                <xsl:value-of select="@accountName"/>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalbfCurr"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalInvoiceCurr"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCreditCurr"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <xsl:if test="$showVat">
                                                <td style="{$money}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@totalVatCurr"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </td>
                                            </xsl:if>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCurr"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalPaymentCurr"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalRefundCurr"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td></td>
                                            </xsl:if>
                                            <td style="{$money} {$DrCrR}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalcfCurr"/>
                                                    <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                    </xsl:for-each>
                                    
                                    <!-- Subtotals -->
                                    <xsl:if test="$row and /*/@foreignCurrencyCount &gt; 0">
                                        <tr >
                                            <td style="{$firstColumnStyle} {$DrCrL} {$left}">
                                                <strong>
                                                    ***Subtotal*** <xsl:value-of select="@code"/>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@totalbfCurr)"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@totalInvoiceCurr)"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@totalCreditCurr)"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <xsl:if test="$showVat">
                                                <td style="{$money}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum($row/@totalVatCurr)"/>
                                                            <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                            </xsl:if>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@totalCurr)"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@totalPaymentCurr)"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@totalRefundCurr)"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <td style="{$money}" >
                                                </td>
                                            </xsl:if>
                                            <td style="{$money} {$DrCrR}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@totalcfCurr)"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                        </tr>
                                        <xsl:if test="not(@uidCurrency = 0)">
                                            <tr >
                                                <td style="{$firstColumnStyle} {$DrCrL} {$left}">
                                                    <strong>
                                                        ***Subtotal*** <xsl:value-of select="/*/currencies/row[@uidCurrency = 0]/@code"/>
                                                    </strong>
                                                </td>
                                                <td style="{$money}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum($row/@totalbf)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                                <td style="{$money}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum($row/@totalInvoice)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                                <td style="{$money}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum($row/@totalCredit)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                                <xsl:if test="$showVat">
                                                    <td style="{$money}" >
                                                        <strong>
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="sum($row/@totalVat)"/>
                                                            </xsl:call-template>
                                                        </strong>
                                                    </td>
                                                </xsl:if>
                                                <td style="{$money}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum($row/@total)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                                <td style="{$money}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum($row/@totalPayment)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                                <td style="{$money}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum($row/@totalRefund)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                                <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                    <td style="{$money}" >
                                                        <strong>
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="sum($row/@gaincf)"/>
                                                            </xsl:call-template>
                                                        </strong>
                                                    </td>
                                                </xsl:if>
                                                <td style="{$money} {$DrCrR}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum($row/@totalcf)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                            </tr>
                                        </xsl:if>
                                    </xsl:if>

                                </xsl:for-each>
                                
                                <xsl:call-template name="blankLine"/>
                                
                                <tr >
                                    <td style="{$firstColumnStyle} {$DrCrL} {$left}">
                                        <strong>
                                            ***Totals***
                                            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                                <xsl:value-of select="/*/currencies/row[@uidCurrency = 0]/@code"/>
                                            </xsl:if>
                                        </strong>
                                    </td>
                                    <td style="{$money}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(accounts/row/@totalbf)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(accounts/row/@totalInvoice)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(accounts/row/@totalCredit)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <xsl:if test="$showVat">
                                        <td style="{$money}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(accounts/row/@totalVat)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                    <td style="{$money}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(accounts/row/@total)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(accounts/row/@totalPayment)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(accounts/row/@totalRefund)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                        <td style="{$money}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(accounts/row/@gaincf)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                    <td style="{$money} {$DrCrR}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(accounts/row/@totalcf)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                </tr>
                                
                                <tr >
                                    <td colspan="4" style="{$DrCrL} {$bottomBorder}">
                                    </td>
                                    <td style="{$bottomBorder}"></td>
                                    <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                        <td style="{$bottomBorder}"></td>
                                    </xsl:if>
                                    <td colspan="4" style="{$DrCrR} {$bottomBorder}">
                                    </td>
                                </tr>

                            </tbody>
                        </table>
                                                
                    </div>
                </div>

                <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                    <br />
                    <xsl:call-template name="exchangeRates"/>
                </xsl:if>


                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template name="blankLine">
        <tr >
            <td colspan="4" style="{$DrCrL}">&#160;
            </td>
            <td></td>
            <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                <td></td>
            </xsl:if>
            <td colspan="4" style="{$DrCrR}">
            </td>
        </tr>
    </xsl:template>
    
</xsl:transform>
