<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="report" select="@report"/>
        <xsl:variable name="totalCost" select="sum(accounts/row/products/row/@costAmount)"/>
        <xsl:variable name="reportName">***Best Sellers***</xsl:variable>
        <xsl:variable name="showDescription" select="@showDescription"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportName"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle"><xsl:value-of select="$reportName"/> ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***From***
                            <xsl:value-of select="@fromDate"/>
                            to
                            <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="{$reportName}" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th colspan="2" style="{$headingsLineStyle}">
                                    </th>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***Qty Sold***
                                    </th>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***Avg Sale Price***
                                    </th>
                                    <xsl:if test="$totalCost = 0">
                                        <th style="{$headingsLineStyle} {$right}">
                                            ***Sales***
                                        </th>
                                    </xsl:if>
                                    <xsl:if test="not($totalCost = 0)">
                                        <th style="{$headingsLineStyle} {$right}">
                                            ***Sales***
                                        </th>
                                        <th style="{$headingsLineStyle} {$right}">
                                            ***Cost***
                                        </th>
                                        <th style="{$headingsLineStyle} {$right}">
                                            ***Profit***
                                        </th>
                                        <th style="{$headingsLineStyle} {$right}">
                                            ***Margin (%)***
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <xsl:for-each select="accounts/row">
                                    <xsl:sort order="descending" data-type="number" select="sum(products/row/@profit)"/>
                                    <tr>
                                        <td colspan="2" style="{$firstColumnStyle} {$DrCrL} {$catName}"><xsl:value-of select="@accountName"/></td>
                                        <td colspan="6" style="{$money} {$DrCrL} {$DrCrR}"></td>
                                    </tr>
                                    
                                    <xsl:variable name="row" select="products/row"/>
                                    
                                    <xsl:for-each select="$row">
                                        <xsl:sort order="descending" data-type="number" select="@profit"/>
                                        
                                        <xsl:variable name="margin" select="100 * (@profit) div @saleAmount"/>
                                        
                                        <tr>
                                            <td style="{$firstColumnStyle} {$DrCrL} {$accountIndent1}">
                                                <xsl:value-of select="@productName"/>
                                            </td>
                                            <td style="{$descColumnStyle}">
                                                <xsl:if test="$showDescription = '1'">
                                                    <xsl:value-of select="@productDesc"/>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$DrCrL}" >
                                                <xsl:call-template name="formatNumber">
                                                    <xsl:with-param name="number" select="@saleQty"/>
                                                    <xsl:with-param name="divisor" select="1000"/>
                                                    <xsl:with-param name="notrail" select="1"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@saleAmount div @saleQty"/>
                                                </xsl:call-template>
                                            </td>
                                            <xsl:if test="$totalCost = 0">
                                                <td style="{$money} {$DrCrR}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@saleAmount"/>
                                                    </xsl:call-template>
                                                </td>
                                            </xsl:if>
                                            <xsl:if test="not($totalCost = 0)">
                                                <td style="{$money}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@saleAmount"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@costAmount"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@profit"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money} {$DrCrR}" >
                                                    <xsl:call-template name="formatNumber">
                                                        <xsl:with-param name="number" select="$margin"/>
                                                        <xsl:with-param name="divisor" select="100"/>
                                                    </xsl:call-template>
                                                </td>
                                            </xsl:if>
                                        </tr>
                                    </xsl:for-each>
                                    
                                    <tr>
                                        <th colspan="2" style="{$firstColumnStyle} {$DrCrL} {$accountIndent1} {$left}">
                                            <strong>***Sub Totals***</strong>
                                        </th>
                                        <td style="{$money} {$DrCrL}" >
                                            <strong>
                                                <xsl:call-template name="formatNumber">
                                                    <xsl:with-param name="number" select="sum($row/@saleQty)"/>
                                                    <xsl:with-param name="divisor" select="1000"/>
                                                    <xsl:with-param name="notrail" select="1"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money}" >
                                            <xsl:if test="not(sum($row/@saleQty) = 0)">
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@saleAmount) div sum($row/@saleQty)"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </xsl:if>
                                        </td>
                                        <xsl:if test="$totalCost = 0">
                                            <td style="{$money} {$DrCrR}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@saleAmount)"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                        </xsl:if>
                                        <xsl:if test="not($totalCost = 0)">
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@saleAmount)"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@costAmount)"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($row/@profit)"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money} {$DrCrR}" >
                                                <strong>
                                                    <xsl:call-template name="formatNumber">
                                                        <xsl:with-param name="number" select="100 * (sum($row/@saleAmount) - sum($row/@costAmount)) div sum($row/@saleAmount)"/>
                                                        <xsl:with-param name="divisor" select="100"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                        </xsl:if>
                                    </tr>

                                </xsl:for-each>
                                

                                <tr>
                                    <td colspan="2" style="{$firstColumnStyle} {$DrCrL} {$catName}"></td>
                                    <xsl:if test="$totalCost = 0">
                                        <td style="{$money} {$DrCrL} {$DrCrR}" colspan="3"></td>
                                    </xsl:if>
                                    <xsl:if test="not($totalCost = 0)">
                                        <td style="{$money} {$DrCrL} {$DrCrR}" colspan="6"></td>
                                    </xsl:if>
                                </tr>
                                
                                <!-- Totals -->
                                <tr >
                                    <th colspan="2" style="{$firstColumnStyle} {$DrCrL} {$bottomBorder} {$left}">
                                        <strong>***Totals***</strong>
                                    </th>
                                    <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                        <strong>
                                            <xsl:call-template name="formatNumber">
                                                <xsl:with-param name="number" select="sum(accounts/row/products/row/@saleQty)"/>
                                                <xsl:with-param name="divisor" select="1000"/>
                                                <xsl:with-param name="notrail" select="1"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money} {$bottomBorder}" >
                                        <xsl:if test="not(sum(accounts/row/products/row/@saleQty) = 0)">
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(accounts/row/products/row/@saleAmount) div sum(accounts/row/products/row/@saleQty)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </xsl:if>
                                    </td>
                                    <xsl:if test="$totalCost = 0">
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(accounts/row/products/row/@saleAmount)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                    <xsl:if test="not($totalCost = 0)">
                                        <td style="{$money} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(accounts/row/products/row/@saleAmount)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(accounts/row/products/row/@costAmount)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(accounts/row/products/row/@saleAmount) - sum(accounts/row/products/row/@costAmount)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatNumber">
                                                    <xsl:with-param name="number" select="100 * (sum(accounts/row/products/row/@saleAmount) - sum(accounts/row/products/row/@costAmount)) div sum(accounts/row/products/row/@saleAmount)"/>
                                                    <xsl:with-param name="divisor" select="100"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                </tr>
                            </tbody>
                        </table>
                        
                        <br />
                        <br />
                        
                        <hr />
                                                
                        <h1 style="{$h1Style}">***Notes***</h1>
                        
                        <p>***BestSellersNotes2***
                        </p>
                        
                    </div>
                </div>
                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
</xsl:transform>
