<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">

        <xsl:variable name="report" select="@report"/>
        <xsl:variable name="showContained" select="@showContained"/>
        <xsl:variable name="showComparison" select="@showComparison"/>
        <xsl:variable name="drTitle">***Asset***</xsl:variable>
        <xsl:variable name="crTitle">***Liability***</xsl:variable>
        
        <xsl:variable name="balanceOnDepreciation" select="@deprecAmount"/>
        
        <xsl:variable name="balanceOnDepreciationComparison" select="@deprecAmountComparison"/>
        
        <xsl:variable name="balanceOnPl" select="sum(categories/row/accounts/row[(@accountCategoryID='EXPENSE' or
        @accountCategoryID='INCOME')]
        [@isContainer='0']/@origTotal)"/>
        
        <xsl:variable name="balanceOnPlComparison" select="sum(categories/row/accounts/row[(@accountCategoryID='EXPENSE' or
        @accountCategoryID='INCOME')]
        [@isContainer='0']/comparison/@origTotal)"/>
        
        <xsl:variable name="balanceOnCustomers" select="sum(categories/row/accounts/row[@accountCategoryID='CUSTOMER' and @isContainer='0']/@total)"/>
        <xsl:variable name="balanceOnCustomersComparison" select="sum(categories/row/accounts/row[@accountCategoryID='CUSTOMER' and @isContainer='0']/comparison/@total)"/>
        
        <xsl:variable name="balanceOnSuppliers" select="sum(categories/row/accounts/row[@accountCategoryID='SUPPLIER' and @isContainer='0']/@total)"/>
        <xsl:variable name="balanceOnSuppliersComparison" select="sum(categories/row/accounts/row[@accountCategoryID='SUPPLIER' and @isContainer='0']/comparison/@total)"/>
        
        <xsl:variable name="vatAccounts" select="categories/row/accounts/row[@isVatAccount='1' or @accountSubCatID='TAXCREDIT'][@isContainer='0']"/>
        
        <xsl:variable name="vatAmount" select="sum($vatAccounts/@total)"/>
        <xsl:variable name="vatAmountComparison" select="sum($vatAccounts/comparison/@total)"/>
        
        <xsl:variable name="cashAccounts" select="categories/row[@cfCategoryID='CASH']/accounts/row[@isContainer='0']"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***Cash Flow Report***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        
                        <h1 style="{$h1Style}" class="mainTitle">***Cash Flow Report*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="Cash Flow Report" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th colspan="2" style="{$headingsLineStyle} {$left}">
                                        ***Account***
                                    </th>
                                    <th colspan="2" style="{$headingsLineStyle} {$center}">
                                        <xsl:value-of select="@fromDate"/> <br/>***to*** <xsl:value-of select="@toDate"/>
                                    </th>
                                    <xsl:if test="$showComparison='Y'">
                                        <th colspan="2" style="{$headingsLineStyle} {$center}">
                                            <xsl:value-of select="@fromDateComparison"/> <br/>***to*** <xsl:value-of select="@toDateComparison"/>
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <xsl:for-each select="categories/row">
                                    <xsl:if test="@cfCategoryID != 'CASH'">
                                        <xsl:call-template name="accountSubCatLine">
                                            <xsl:with-param name="title">***Cash Flow from*** <xsl:value-of select="@description"/></xsl:with-param>
                                        </xsl:call-template>
                                        
                                        <xsl:variable name="row" select="accounts/row[not(number(@total)=0 and (not($showComparison='Y') or number(comparison/@total)=0))][($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]"/>
                                        
                                        <xsl:if test="@cfCategoryID = 'OPS'">
                                            <xsl:if test="$balanceOnPl != 0 or $balanceOnPlComparison != 0">
                                                <xsl:call-template name="account">
                                                    <xsl:with-param name="accountName">***Net Income***</xsl:with-param>
                                                    <xsl:with-param name="total" select="$balanceOnPl"/>
                                                    <xsl:with-param name="comparisonTotal">
                                                        <xsl:if test="$showComparison='Y'">
                                                            <xsl:value-of select="$balanceOnPlComparison"/>
                                                        </xsl:if>
                                                    </xsl:with-param>
                                                    <xsl:with-param name="scaleBalance" select="1"/>
                                                </xsl:call-template>
                                            </xsl:if>
                                            <xsl:if test="$balanceOnDepreciation != 0 or $balanceOnDepreciationComparison != 0">
                                                <xsl:call-template name="account">
                                                    <xsl:with-param name="accountName">***Depreciation***</xsl:with-param>
                                                    <xsl:with-param name="total" select="$balanceOnDepreciation"/>
                                                    <xsl:with-param name="comparisonTotal">
                                                        <xsl:if test="$showComparison='Y'">
                                                            <xsl:value-of select="$balanceOnDepreciationComparison"/>
                                                        </xsl:if>
                                                    </xsl:with-param>
                                                    <xsl:with-param name="scaleBalance" select="1"/>
                                                </xsl:call-template>
                                            </xsl:if>
                                            <xsl:if test="$balanceOnCustomers != 0 or $balanceOnCustomersComparison != 0">
                                                <xsl:call-template name="account">
                                                    <xsl:with-param name="accountName">***Decrease in Customers Balance***</xsl:with-param>
                                                    <xsl:with-param name="total" select="$balanceOnCustomers"/>
                                                    <xsl:with-param name="comparisonTotal">
                                                        <xsl:if test="$showComparison='Y'">
                                                            <xsl:value-of select="$balanceOnCustomersComparison"/>
                                                        </xsl:if>
                                                    </xsl:with-param>
                                                    <xsl:with-param name="scaleBalance" select="1"/>
                                                </xsl:call-template>
                                            </xsl:if>
                                            <xsl:if test="$balanceOnSuppliers != 0 or $balanceOnSuppliersComparison != 0">
                                                <xsl:call-template name="account">
                                                    <xsl:with-param name="accountName">***Increase in Suppliers Balance***</xsl:with-param>
                                                    <xsl:with-param name="total" select="$balanceOnSuppliers"/>
                                                    <xsl:with-param name="comparisonTotal">
                                                        <xsl:if test="$showComparison='Y'">
                                                            <xsl:value-of select="$balanceOnSuppliersComparison"/>
                                                        </xsl:if>
                                                    </xsl:with-param>
                                                    <xsl:with-param name="scaleBalance" select="1"/>
                                                </xsl:call-template>
                                            </xsl:if>
                                            <xsl:if test="$vatAmount != 0 or $vatAmountComparison != 0">
                                                <xsl:call-template name="account">
                                                    <xsl:with-param name="accountName">***Increase in taxes payable***</xsl:with-param>
                                                    <xsl:with-param name="total" select="$vatAmount"/>
                                                    <xsl:with-param name="comparisonTotal">
                                                        <xsl:if test="$showComparison='Y'">
                                                            <xsl:value-of select="$vatAmountComparison"/>
                                                        </xsl:if>
                                                    </xsl:with-param>
                                                    <xsl:with-param name="scaleBalance" select="1"/>
                                                </xsl:call-template>
                                            </xsl:if>
                                        </xsl:if>
                                        
                                        <xsl:for-each select="$row">
                                            <xsl:variable name="uidAccount" select="@uidAccount"/>
                                            
                                            <xsl:choose>
                                                <xsl:when test="@accountCategoryID='CUSTOMER'">
                                                </xsl:when>
                                                <xsl:when test="@accountCategoryID='SUPPLIER'">
                                                </xsl:when>
                                                <xsl:when test="@accountCategoryID='EXPENSE' or @accountCategoryID='INCOME'">
                                                </xsl:when>
                                                <xsl:when test="$vatAccounts[@uidAccount=$uidAccount or @uidAccountParent=$uidAccount]">
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:call-template name="accountLine">
                                                        <xsl:with-param name="row" select="$row"/>
                                                        <xsl:with-param name="scaleBalance" select="1"/>
                                                    </xsl:call-template>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            
                                        </xsl:for-each>
                                        
                                        <xsl:call-template name="account">
                                            <xsl:with-param name="bold">Y</xsl:with-param>
                                            <xsl:with-param name="accountName"><xsl:value-of select="@description"/> (***total***)</xsl:with-param>
                                            <xsl:with-param name="total" select="sum(accounts/row[($showContained='0' and @uidAccountParent='0') or
                                            ($showContained='1' and @isContainer='0')]/@total)"/>
                                            <xsl:with-param name="comparisonTotal">
                                                <xsl:if test="$showComparison='Y'">
                                                    <xsl:value-of select="sum(accounts/row[($showContained='0' and @uidAccountParent='0') or 
                                                    ($showContained='1' and @isContainer='0')]/comparison/@total)"/>
                                                </xsl:if>
                                            </xsl:with-param>
                                            <xsl:with-param name="scaleBalance" select="1"/>
                                        </xsl:call-template>
                                    </xsl:if>
                                </xsl:for-each>
                                
                                <!-- Totals -->
                                <xsl:call-template name="blankAccountLine"/>
                                <xsl:call-template name="account">
                                    <xsl:with-param name="bold">Y</xsl:with-param>
                                    <xsl:with-param name="indent">0</xsl:with-param>
                                    <xsl:with-param name="accountName">***Total Cash Flow***</xsl:with-param>
                                    <xsl:with-param name="total" select="sum($cashAccounts/@total)"/>
                                    <xsl:with-param name="comparisonTotal">
                                        <xsl:if test="$showComparison='Y'">
                                            <xsl:value-of select="sum($cashAccounts/comparison/@total)"/>
                                        </xsl:if>
                                    </xsl:with-param>
                                    <xsl:with-param name="scaleBalance" select="1"/>
                                </xsl:call-template>
                                
                                <xsl:call-template name="blankAccountLine"/>
                                
                                <xsl:call-template name="account">
                                    <xsl:with-param name="bold">Y</xsl:with-param>
                                    <xsl:with-param name="indent">0</xsl:with-param>
                                    <xsl:with-param name="accountName">***Cash Balance At Start***</xsl:with-param>
                                    <xsl:with-param name="total" select="sum($cashAccounts/@totalbf)"/>
                                    <xsl:with-param name="comparisonTotal">
                                        <xsl:if test="$showComparison='Y'">
                                            <xsl:value-of select="sum($cashAccounts/comparison/@totalbf)"/>
                                        </xsl:if>
                                    </xsl:with-param>
                                    <xsl:with-param name="scaleBalance" select="1"/>
                                </xsl:call-template>

                                <xsl:call-template name="account">
                                    <xsl:with-param name="bold">Y</xsl:with-param>
                                    <xsl:with-param name="indent">0</xsl:with-param>
                                    <xsl:with-param name="accountName">***Total Cash Flow***</xsl:with-param>
                                    <xsl:with-param name="total" select="sum($cashAccounts/@total)"/>
                                    <xsl:with-param name="comparisonTotal">
                                        <xsl:if test="$showComparison='Y'">
                                            <xsl:value-of select="sum($cashAccounts/comparison/@total)"/>
                                        </xsl:if>
                                    </xsl:with-param>
                                    <xsl:with-param name="scaleBalance" select="1"/>
                                </xsl:call-template>

                                <xsl:call-template name="account">
                                    <xsl:with-param name="bold">Y</xsl:with-param>
                                    <xsl:with-param name="indent">0</xsl:with-param>
                                    <xsl:with-param name="accountName">***Cash Balance At End***</xsl:with-param>
                                    <xsl:with-param name="total" select="sum($cashAccounts/@totalbf) + sum($cashAccounts/@total)"/>
                                    <xsl:with-param name="comparisonTotal">
                                        <xsl:if test="$showComparison='Y'">
                                            <xsl:value-of select="sum($cashAccounts/comparison/@totalbf) + sum($cashAccounts/comparison/@total)"/>
                                        </xsl:if>
                                    </xsl:with-param>
                                    <xsl:with-param name="scaleBalance" select="1"/>
                                </xsl:call-template>
                                
                                <tr >
                                    <th colspan="2" style="{$firstColumnStyle} {$DrCrL} {$bottomBorder}">
                                    </th>
                                    <xsl:if test="not($showComparison='Y')">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                        </td>
                                    </xsl:if>
                                    <xsl:if test="$showComparison='Y'">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                        </td>
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                        </td>
                                    </xsl:if>
                                </tr>
                                
                            </tbody>
                        </table>
                    </div>
                </div>
                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
</xsl:transform>