<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="numberStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:variable name="bodyStyle">background-color:var(--background-color);color:var(--text-color);margin:12px 20px;padding:0px;font-family:-apple-system-body,Arial,sans-serif;</xsl:variable>
    <xsl:variable name="tableWrapperOuter">background-color: var(--background-color); padding: 0px;</xsl:variable>
    <xsl:variable name="tableWrapperInner">padding: 0 0 2px;</xsl:variable>
    <xsl:variable name="headingsLineStyle">background-color: var(--heading-background-color);font-size:14px;padding:10px 10px 5px;border: 1px solid #DDD;</xsl:variable>
    <xsl:variable name="headingsTopStyle">background-color: var(--heading-background-color);font-size:14px;padding:10px 10px 5px;border-left: 1px solid #DDD;border-right: 1px solid #DDD;border-top: 1px solid #DDD;</xsl:variable>
    <xsl:variable name="headingsBottomStyle">background-color: var(--heading-background-color);font-size:14px;padding:5px 10px 10px;border-bottom: 1px solid #DDD; border-left: 1px solid #DDD; border-right: 1px solid #DDD;</xsl:variable>
    <xsl:variable name="headingUnderline">border-bottom:1px solid #DDD;</xsl:variable>
    <xsl:variable name="left">text-align: left;</xsl:variable>
    <xsl:variable name="center">text-align: center;</xsl:variable>
    <xsl:variable name="right">text-align: right;</xsl:variable>
    <xsl:variable name="h1Style">margin:0;font-size: 18px;font-family:-apple-system-headline,Arial,sans-serif;font-weight:bold;color:var(--heading1-text-color);</xsl:variable>
    <xsl:variable name="h2Style">margin:0 0 5px;font-size:16px;font-weight:normal;color:var(--heading-text-color);font-family:-apple-system-subheadline,Arial,sans-serif;</xsl:variable>
    <xsl:variable name="h3Style">margin:0 0 5px;font-size:12px;font-weight:normal;color:var(--heading-text-color);font-family:-apple-system-subheadline,Arial,sans-serif;</xsl:variable>
    <xsl:variable name="firstColumnStyle">padding:5px 10px;text-align:left;white-space:nowrap;</xsl:variable>
    <xsl:variable name="descColumnStyle">padding:5px 10px;text-align:left;</xsl:variable>
    <xsl:variable name="accountIndent0">padding-left:10px;</xsl:variable>
    <xsl:variable name="accountIndent1">padding-left:20px;</xsl:variable>
    <xsl:variable name="accountIndent2">padding-left:30px;</xsl:variable>
    <xsl:variable name="accountIndent3">padding-left:40px;</xsl:variable>
    <xsl:variable name="money">padding:5px 10px;text-align:right;white-space:nowrap;</xsl:variable>
    <xsl:variable name="DrCrL">border-left:1px solid #DDD;</xsl:variable>
    <xsl:variable name="DrCrR">border-right:1px solid #DDD;</xsl:variable>
    <xsl:variable name="bottomBorder">border-bottom:1px solid #DDD;padding:5px 10px 10px;</xsl:variable>
    <xsl:variable name="bold">font-weight:bold;</xsl:variable>    
    <xsl:variable name="budgetGood">color:green;</xsl:variable>    
    <xsl:variable name="budgetBad">color:red;</xsl:variable>
    <xsl:variable name="warning">color:red;</xsl:variable>
    <xsl:variable name="vatBoxLabel">border:1px solid #DDD;padding:10px;</xsl:variable>
    <xsl:variable name="vatBoxNumber">border:1px solid #DDD;padding:10px;font-weight:bold;</xsl:variable>
    <xsl:variable name="vatBoxAmount">border:1px solid #DDD;padding:10px;</xsl:variable>
    <xsl:variable name="greySubTotalsMonthly">background-color: var(--heading-background-color);border-top:1px solid #DDD;border-bottom:1px solid #DDD;</xsl:variable>
    <xsl:variable name="catName">text-transform:uppercase;font-size:90%;color:var(--category-name-text-color);padding-top:20px;</xsl:variable>
    <xsl:variable name="lineover">border-top:1px solid grey;</xsl:variable>
    <xsl:variable name="tableStyle">border-collapse: collapse; border-spacing: 0px; font-size:12px;</xsl:variable>
    <xsl:variable name="preformatted">white-space: pre;</xsl:variable>
    
    <xsl:template name="cssStyles">
        <style type="text/css" media="all">
            :root {
            --background-color: #FFF;
            --heading-background-color: #F0F0F0;
            --heading1-text-color: #25255b;
            --heading-text-color: #666;
            --text-color: #000;
            --category-name-text-color: #808090;
            }
        </style>
        <link rel="stylesheet" href="report.css"/>
        <link rel="stylesheet" href="ios.css"/>
        <style type="text/css" media="all">
            td {
            padding: 0px;
            vertical-align: top;
            }
            .paddedTable td {
            padding: 5px 10px;
            }
        </style>
    </xsl:template>
    
    <xsl:template name="messages">
        <xsl:if test="/*/warnings/row">
            <ul>
                <xsl:for-each select="/*/warnings/row">
                    <li style="{$warning}">
                        <xsl:value-of select="."/>
                    </li>
                </xsl:for-each>
            </ul>
            <br />
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="preparedOn">
        <xsl:param name="message"/>
        <br />
        <div style="{$h3Style}">
            <xsl:value-of select="$message"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="/*/@runTime"/>
        </div>
    </xsl:template>

    <xsl:template name="formatAccountName">
        <xsl:param name="row"/>
        <xsl:choose>
            <xsl:when test="$row/@uidAccountParent &gt; 0">
                <xsl:value-of select="$row/@parentAccountName"/>
                <xsl:text> &gt; </xsl:text>
                <xsl:value-of select="$row/@accountName"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$row/@accountName"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="blankAccountLine">
        <xsl:variable name="showComparison" select="/root/@showComparison"/>
        <tr>
            <td style="{$firstColumnStyle} {$DrCrL}" colspan="2" >&#160;</td>
            <td style="{$money} {$DrCrL}" ></td>
            <td style="{$money} {$DrCrR}" ></td>
            <xsl:if test="$showComparison='Y'">
                <td style="{$money} {$DrCrL}" ></td>
                <td style="{$money} {$DrCrR}" ></td>
            </xsl:if>
        </tr>
    </xsl:template>
    
    <xsl:template name="accountSubCatLine">
        <xsl:param name="title"/>
        <xsl:variable name="showComparison" select="/root/@showComparison"/>
        <tr>
            <td style="{$firstColumnStyle} {$DrCrL} {$catName}" colspan="2"><xsl:value-of select="$title"/></td>
            <td style="{$money} {$DrCrL}" ></td>
            <td style="{$money} {$DrCrR}" ></td>
            <xsl:if test="$showComparison='Y'">
                <td style="{$money} {$DrCrL}" ></td>
                <td style="{$money} {$DrCrR}" ></td>
            </xsl:if>
        </tr>
    </xsl:template>

    <xsl:template name="accountLines">
        <xsl:param name="row"/>
        
        <xsl:for-each select="$row">
            <xsl:call-template name="accountLine">
                <xsl:with-param name="row" select="$row"/>
            </xsl:call-template>
        </xsl:for-each>
    </xsl:template>

    <xsl:template name="accountLine">
        <xsl:param name="row"/>
        <xsl:param name="scaleBalance"/>
        <xsl:variable name="currentRow" select="position()"/>
        <xsl:variable name="showComparison" select="/root/@showComparison"/>
        <xsl:variable name="parentName" select="@parentAccountName"/>
        
        <xsl:if test="$currentRow = 1 or @uidAccountParent != $row[$currentRow - 1]/@uidAccountParent">
            <xsl:if test="@uidAccountParent &gt; 0">
                <xsl:call-template name="formatAccountLine">
                    <xsl:with-param name="accountName"><xsl:value-of select="$parentName"/></xsl:with-param>
                </xsl:call-template>
            </xsl:if>
        </xsl:if>
        
        <xsl:call-template name="account">
            <xsl:with-param name="accountName" select="@accountName"/>
            <xsl:with-param name="parentName" select="$parentName"/>
            <xsl:with-param name="indent">
                <xsl:choose>
                    <xsl:when test="@uidAccountParent &gt; 0">2</xsl:when>
                    <xsl:otherwise>1</xsl:otherwise>
                </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="total" select="@total"/>
            <xsl:with-param name="comparisonTotal">
                <xsl:if test="$showComparison='Y'">
                    <xsl:value-of select="comparison/@total"/>
                </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="scaleBalance">
                <xsl:choose>
                    <xsl:when test="$scaleBalance">
                        <xsl:value-of select="$scaleBalance"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="@scaleBalance"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="scaleBalanceComparison">
                <xsl:choose>
                    <xsl:when test="$scaleBalance">
                        <xsl:value-of select="$scaleBalance"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="comparison/@scaleBalance"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="account">
        <xsl:param name="accountName"/>
        <xsl:param name="parentName"/>
        <xsl:param name="total"/>
        <xsl:param name="comparisonTotal"/>
        <xsl:param name="scaleBalance"></xsl:param>
        <xsl:param name="scaleBalanceComparison"></xsl:param>
        <xsl:param name="bold"></xsl:param>
        <xsl:param name="indent">1</xsl:param>

        <xsl:variable name="accountNameCsv">
            <xsl:choose>
                <xsl:when test="$parentName != ''">
                    <xsl:value-of select="$accountName"/>
                    <xsl:text> (</xsl:text>
                    <xsl:value-of select="$parentName"/>
                    <xsl:text>)</xsl:text>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="$accountName"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:call-template name="formatAccountLine">
            <xsl:with-param name="accountName"><xsl:value-of select="$accountName"/></xsl:with-param>
            <xsl:with-param name="accountNameCsv"><xsl:value-of select="$accountNameCsv"/></xsl:with-param>
            <xsl:with-param name="totalDr">
                <xsl:choose>
                    <xsl:when test="$scaleBalance">
                        <xsl:if test="$scaleBalance = '1'">
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="$total"/>
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="$total &gt;= 0">
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="$total"/>
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="totalCr">
                <xsl:choose>
                    <xsl:when test="$scaleBalance">
                        <xsl:if test="$scaleBalance = '-1'">
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="-1 * $total"/>
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="$total &lt; 0">
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="-1 * $total"/>
                            </xsl:call-template>
                        </xsl:if>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="comparisonDr">
                <xsl:if test="not($comparisonTotal='')">
                    <xsl:choose>
                        <xsl:when test="$scaleBalanceComparison">
                            <xsl:if test="$scaleBalanceComparison = '1'">
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="$comparisonTotal"/>
                                </xsl:call-template>
                            </xsl:if>
                        </xsl:when>
                        <xsl:when test="$scaleBalance">
                            <xsl:if test="$scaleBalance = '1'">
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="$comparisonTotal"/>
                                </xsl:call-template>
                            </xsl:if>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:if test="$comparisonTotal &gt;= 0">
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="$comparisonTotal"/>
                                </xsl:call-template>
                            </xsl:if>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="comparisonCr">
                <xsl:if test="not($comparisonTotal='')">
                    <xsl:choose>
                        <xsl:when test="$scaleBalanceComparison">
                            <xsl:if test="$scaleBalanceComparison = '-1'">
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="-1 * $comparisonTotal"/>
                                </xsl:call-template>
                            </xsl:if>
                        </xsl:when>
                        <xsl:when test="$scaleBalance">
                            <xsl:if test="$scaleBalance = '-1'">
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="-1 * $comparisonTotal"/>
                                </xsl:call-template>
                            </xsl:if>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:if test="$comparisonTotal &lt; 0">
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="-1 * $comparisonTotal"/>
                                </xsl:call-template>
                            </xsl:if>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="bold" select="$bold"/>
            <xsl:with-param name="indent" select="$indent"/>
        </xsl:call-template>

    </xsl:template>
    
    <xsl:template name="formatAccountLine">
        <xsl:param name="accountName"/>
        <xsl:param name="accountNameCsv"/>
        <xsl:param name="totalDr"/>
        <xsl:param name="totalCr"/>
        <xsl:param name="comparisonDr"/>
        <xsl:param name="comparisonCr"/>
        <xsl:param name="bold"></xsl:param>
        <xsl:param name="indent">1</xsl:param>
        <xsl:variable name="showComparison" select="/root/@showComparison"/>
        <tr class="accountRow" uidAccount="{./@uidAccount}" uidSubCat="{./@uidAccountSubCat}">
            <xsl:attribute name="style">
                <xsl:if test="$bold='Y'">font-weight:bold;</xsl:if>
            </xsl:attribute>
            <td style="{$firstColumnStyle} {$DrCrL} {$accountIndent2}" colspan="2">
                <xsl:attribute name="style">
                    <xsl:value-of select="$firstColumnStyle"/>
                    <xsl:value-of select="$DrCrL"/>
                    <xsl:choose>
                        <xsl:when test="$indent='3'"><xsl:value-of select="$accountIndent3"/></xsl:when>
                        <xsl:when test="$indent='2'"><xsl:value-of select="$accountIndent2"/></xsl:when>
                        <xsl:when test="$indent='1'"><xsl:value-of select="$accountIndent1"/></xsl:when>
                        <xsl:otherwise></xsl:otherwise>
                    </xsl:choose>
                </xsl:attribute>
                <xsl:choose>
                    <xsl:when test="$accountNameCsv">
                        <span cellText="{$accountNameCsv}">
                            <xsl:copy-of select="$accountName"/>
                        </span>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:copy-of select="$accountName"/>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td style="{$money} {$DrCrL}" ><xsl:copy-of select="$totalDr"/></td>
            <td style="{$money} {$DrCrR}" ><xsl:copy-of select="$totalCr"/></td>
            <xsl:if test="not($comparisonDr='' and $comparisonCr='') or $showComparison='Y'">
                <td style="{$money} {$DrCrL}" ><xsl:copy-of select="$comparisonDr"/></td>
                <td style="{$money} {$DrCrR}" ><xsl:copy-of select="$comparisonCr"/></td>
            </xsl:if>
        </tr>
    </xsl:template>
    
</xsl:transform>

