<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="exchangeRateGainsCommon.xslt"/>
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">

        <!-- report is CUSTOMER or SUPPLIER -->
        <xsl:variable name="report" select="@report"/>
        <xsl:variable name="reportName">
            <xsl:choose>
                <xsl:when test="$report = 'CUSTOMER'">
                    <xsl:text>***Customers Aged Debt Report***</xsl:text>
                </xsl:when>
                <xsl:when test="$report = 'SUPPLIER'">
                    <xsl:text>***Suppliers Aged Debt Report***</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="salesOrPurchases">
            <xsl:choose>
                <xsl:when test="$report = 'CUSTOMER'">
                    <xsl:text>***Sales to Customers***</xsl:text>
                </xsl:when>
                <xsl:when test="$report = 'SUPPLIER'">
                    <xsl:text>***Purchases from Suppliers***</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportName"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle"><xsl:value-of select="$reportName"/> ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Balances on***
                            <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <xsl:variable name="rowsNonZero" select="/*/accounts/row[not(number(@total)=0)]"/>

                        <table id="mainTable" title="{$reportName}" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th style="{$headingsLineStyle} {$left}">
                                        ***Account***
                                    </th>
                                    <xsl:for-each select="/*/slots/row">
                                        <th style="{$headingsLineStyle} {$right}">
                                            <xsl:value-of select="@label"/>
                                        </th>
                                    </xsl:for-each>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***Total***
                                    </th>
                                </tr>
                                
                                <xsl:for-each select="currencies/row">
                                    <xsl:variable name="uidCurrency" select="@uidCurrency"/>
                                    <xsl:variable name="row" select="$rowsNonZero[@uidCurrency=$uidCurrency]"/>
                                    
                                    <xsl:if test="$row">
                                        <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                            <tr>
                                                <td colspan="{count(/*/slots/row) + 1}" style="{$firstColumnStyle} {$DrCrL} {$catName}" >
                                                    <xsl:value-of select="@name"/>
                                                </td>
                                                <td style="{$money} {$DrCrR}" >
                                                </td>
                                            </tr>
                                        </xsl:if>
                                        
                                        <xsl:for-each select="$row">
                                            <xsl:variable name="uidAccount" select="@uidAccount"/>

                                            <tr>
                                                <td style="{$firstColumnStyle} {$DrCrL}" >
                                                    <xsl:value-of select="@accountName"/>
                                                </td>
                                                <xsl:for-each select="/*/slots/row">
                                                    <td style="padding:5px 10px;text-align:right;" >
                                                        <xsl:if test="accounts/row[@uidAccount=$uidAccount]">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="accounts/row[@uidAccount=$uidAccount]/@amountCurr"/>
                                                                <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                </xsl:for-each>
                                                <td style="{$money} {$DrCrR}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum(/*/slots/row/accounts/row[@uidAccount=$uidAccount]/@amountCurr)"/>
                                                            <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                        
                                        <!-- Subtotals -->
                                        <tr >
                                            <td style="{$firstColumnStyle} {$DrCrL} {$left}">
                                                <strong>
                                                    <xsl:choose>
                                                        <xsl:when test="/*/@foreignCurrencyCount &gt; 0">
                                                            ***Subtotal*** <xsl:value-of select="@code"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            ***Total***
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </strong>
                                            </td>
                                            <xsl:for-each select="/*/slots/row">
                                                <td style="{$money}" >
                                                    <xsl:if test="not(sum(accounts/row[@uidCurrency=$uidCurrency]/@amountCurr) = 0)">
                                                        <strong>
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="sum(accounts/row[@uidCurrency=$uidCurrency]/@amountCurr)"/>
                                                                <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                            </xsl:call-template>
                                                        </strong>
                                                    </xsl:if>
                                                </td>
                                            </xsl:for-each>
                                            <td style="{$money} {$DrCrR}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum(/*/slots/row/accounts/row[@uidCurrency=$uidCurrency]/@amountCurr)"/>
                                                        <xsl:with-param name="uidCurrency" select="$uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                        </tr>

                                        <xsl:if test="not($uidCurrency = 0)">
                                            <tr >
                                                <td style="{$firstColumnStyle} {$DrCrL} {$left}">
                                                    <strong>
                                                        ***TotalsConvertedTo*** <xsl:value-of select="/*/currencies/row[@uidCurrency = 0]/@code"/>
                                                    </strong>
                                                </td>
                                                <xsl:for-each select="/*/slots/row">
                                                    <td style="{$money}" >
                                                        <xsl:if test="not(sum(accounts/row[@uidCurrency=$uidCurrency]/@amount) = 0)">
                                                            <strong>
                                                                <xsl:call-template name="formatCurrency">
                                                                    <xsl:with-param name="pence" select="sum(accounts/row[@uidCurrency=$uidCurrency]/@amount)"/>
                                                                </xsl:call-template>
                                                            </strong>
                                                        </xsl:if>
                                                    </td>
                                                </xsl:for-each>
                                                <td style="{$money} {$DrCrR}" >
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum(/*/slots/row/accounts/row[@uidCurrency=$uidCurrency]/@amount)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </td>
                                            </tr>
                                        </xsl:if>
                                    </xsl:if>
                                </xsl:for-each>

                                <xsl:call-template name="blankLine"/>
                                
                                <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                    <tr >
                                        <td style="{$firstColumnStyle} {$DrCrL} {$left}">
                                            <strong>
                                                ***Totals*** <xsl:value-of select="/*/currencies/row[@uidCurrency = 0]/@code"/>
                                            </strong>
                                        </td>
                                        <xsl:for-each select="/*/slots/row">
                                            <td style="{$money}" >
                                                <xsl:if test="not(sum(accounts/row/@amount) = 0)">
                                                    <strong>
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum(accounts/row/@amount)"/>
                                                        </xsl:call-template>
                                                    </strong>
                                                </xsl:if>
                                            </td>
                                        </xsl:for-each>
                                        <td style="{$money} {$DrCrR}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(/*/slots/row/accounts/row/@amount)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </tr>
                                </xsl:if>
                                
                                <tr >
                                    <td style="{$DrCrL} {$bottomBorder}">
                                    </td>
                                    <td colspan="{count(/*/slots/row)}" style="{$bottomBorder}">
                                    </td>
                                    <td style="{$DrCrR} {$bottomBorder}">
                                    </td>
                                </tr>

                            </tbody>
                        </table>
                    </div>
                </div>
                
                <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                    <br />
                    <xsl:call-template name="exchangeRates"/>
                </xsl:if>
                
                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template name="blankLine">
        <tr >
            <td style="{$DrCrL}">&#160;
            </td>
            <td colspan="{count(/*/slots/row)}">
            </td>
            <td style="{$DrCrR}">
            </td>
        </tr>
    </xsl:template>

</xsl:transform>
