<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>

    <xsl:template name="gainsLosses">
        <xsl:variable name="row" select="/*/gains/row"/>
        <xsl:variable name="businessCurrency" select="/*/currencies/row[@uidCurrency = '0']"/>
        
        <div class="tableWrapperOuter" style="{$tableWrapperOuter}">
            <div class="tableWrapperInner" style="{$tableWrapperInner}">
                
                <div>
                    <h1 style="{$h1Style}">***ExchangeRateGainsLossesUnrealised***</h1>
                    <br/>
                    <table title="***ExchangeRateGainsLossesUnrealised***" style="{$tableStyle}">
                        <colgroup>
                            <col style="{$DrCrL}"/>
                            <col style="{$DrCrR}"/>
                            <col />
                            <col />
                            <col />
                            <col style="{$DrCrR}"/>
                        </colgroup>
                        <tbody>
                            <tr>
                                <th colspan="2" style="{$headingsLineStyle}">
                                </th>
                                <th colspan="4" style="{$headingsLineStyle} {$center}">
                                    ***BusinessCurrency***  (<xsl:value-of select="/*/currencies/row[@uidCurrency = 0]/@code"/>)
                                </th>
                            </tr>

                            <tr>
                                <th style="{$headingsLineStyle} {$bold} {$left}">
                                    ***Account***
                                </th>
                                <th style="{$headingsLineStyle} {$bold} {$right}">
                                    ***Balance***
                                </th>
                                <th style="{$headingsLineStyle} {$bold} {$right}">
                                    ***Rate***
                                </th>
                                <th style="{$headingsLineStyle} {$bold} {$right}">
                                    ***AmountConverted***
                                </th>
                                <th style="{$headingsLineStyle} {$bold} {$right}">
                                    ***AmountUnconverted***
                                </th>
                                <th style="{$headingsLineStyle} {$bold} {$right}">
                                    ***GainsLosses***
                                </th>
                            </tr>

                            <xsl:call-template name="blankGainsLossesLine"/>

                            <xsl:variable name="showPreviousPeriod">
                                <xsl:if test="$row[not(@totalCurr_prev = 0) or not(@total_orig_prev = 0) or not (@total_prev = 0)]">
                                    <xsl:text>1</xsl:text>
                                </xsl:if>
                            </xsl:variable>
                            
                            <xsl:for-each select="$row">
                                <xsl:variable name="uidCurrency" select="@uidCurrency"/>
                                <xsl:variable name="currency" select="/*/currencies/row[@uidCurrency = $uidCurrency]"/>

                                <xsl:choose>
                                    <xsl:when test="$showPreviousPeriod = 1">
                                        <tr>
                                            <td style="{$firstColumnStyle}">
                                                <xsl:value-of select="@accountName"/>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:value-of select="$currency/@code"/>
                                            </td>
                                            <td></td>
                                            <td colspan="3"></td>
                                        </tr>
                                        
                                        <tr>
                                            <xsl:variable name="exchangeRate" select="$currency/exchangeRates/row[@dtype = 0]"/>
                                            
                                            <td style="{$firstColumnStyle}">
                                                ***B/F***
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCurr_prev"/>
                                                    <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <span cellValue="{$exchangeRate/@rate}">
                                                    <xsl:if test="$exchangeRate/@estimated">
                                                        <xsl:text>* </xsl:text>
                                                    </xsl:if>
                                                    
                                                    <xsl:call-template name="formatExchRate">
                                                        <xsl:with-param name="rate" select="$exchangeRate/@rate"/>
                                                    </xsl:call-template>
                                                </span>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total_prev"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total_orig_prev"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total_gain_prev"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                        
                                        <tr>
                                            <xsl:variable name="exchangeRate" select="$currency/exchangeRates/row[@dtype = 1]"/>

                                            <td style="{$firstColumnStyle}">
                                                <xsl:value-of select="/*/@toDate"/>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCurr + @totalCurr_prev"/>
                                                    <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <span cellValue="{$exchangeRate/@rate}">
                                                    <xsl:if test="$exchangeRate/@estimated">
                                                        <xsl:text>* </xsl:text>
                                                    </xsl:if>
                                                    
                                                    <xsl:call-template name="formatExchRate">
                                                        <xsl:with-param name="rate" select="$exchangeRate/@rate"/>
                                                    </xsl:call-template>
                                                </span>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total + @total_prev - @total_gain_prev"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total_orig + @total_orig_prev"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total_gain"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                        
                                        <tr>
                                            <td style="{$firstColumnStyle}">
                                                <strong>***Difference***</strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@totalCurr"/>
                                                        <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@total - @total_gain_prev"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@total_orig"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@total_gain - @total_gain_prev"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                        </tr>

                                        <xsl:call-template name="blankGainsLossesLine"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <tr>
                                            <xsl:variable name="exchangeRate" select="$currency/exchangeRates/row[@dtype = 1]"/>

                                            <td style="{$firstColumnStyle}">
                                                <xsl:value-of select="@accountName"/>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalCurr"/>
                                                    <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <span cellValue="{$exchangeRate/@rate}">
                                                    <xsl:if test="$exchangeRate/@estimated">
                                                        <xsl:text>* </xsl:text>
                                                    </xsl:if>
                                                    
                                                    <xsl:call-template name="formatExchRate">
                                                        <xsl:with-param name="rate" select="$exchangeRate/@rate"/>
                                                    </xsl:call-template>
                                                </span>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total_orig"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total_gain"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                        
                                    </xsl:otherwise>
                                </xsl:choose>

                            </xsl:for-each>
                            
                            <!-- Totals -->
                            <tr>
                                <xsl:variable name="totalPrev" select="sum($row/@total_gain_prev)"/>
                                <xsl:variable name="totalThis" select="sum($row/@total_gain)"/>
                                <td style="{$firstColumnStyle}">
                                    <strong>***TotalGains***</strong>
                                </td>
                                <td></td>
                                <td></td>
                                <td colspan="2"></td>
                                <td style="{$money}" >
                                    <strong>
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$totalThis - $totalPrev"/>
                                        </xsl:call-template>
                                    </strong>
                                </td>
                            </tr>
                            
                            <tr>
                                <td colspan="2" style="{$bottomBorder}"></td>
                                <td colspan="4" style="{$bottomBorder}">
                                    <xsl:if test="/*/currencies/row/exchangeRates/row[@estimated]">
                                        <div style="{$h3Style}">
                                            * ***ContainsEstimatedRates***
                                        </div>
                                    </xsl:if>
                                </td>
                            </tr>
                            
                        </tbody>
                    </table>
                    
                </div>
                
            </div>
        </div>
    </xsl:template>

    <xsl:template name="blankGainsLossesLine">
        <tr>
            <td colspan="2">&#160;</td>
            <td colspan="1"></td>
            <td colspan="3"></td>
        </tr>
    </xsl:template>

    <xsl:template name="exchangeRates">
        <xsl:variable name="businessCurrency" select="/*/currencies/row[@uidCurrency = '0']"/>
        <xsl:variable name="dates" select="/*/currencies/row[1]/exchangeRates/row"/>
        
        <div class="tableWrapperOuter" style="{$tableWrapperOuter}">
            <div class="tableWrapperInner" style="{$tableWrapperInner}">
                
                <div>
                    <h1 style="{$h1Style}">***ExchangeRates***</h1>
                    <br/>
                    <table title="***ExchangeRates***" style="{$tableStyle}">
                        <colgroup>
                            <col style="{$DrCrL}"/>
                            <xsl:if test="count($dates) &gt; 1">
                                <col span="{count($dates) - 1}"/>
                            </xsl:if>
                            <col style="{$DrCrR}"/>
                        </colgroup>
                        <tbody>
                            <tr>
                                <th style="{$headingsLineStyle} {$left}">
                                </th>
                                <th colspan="{count($dates)}" style="{$headingsLineStyle} {$center}">
                                    ***Rate***
                                    <xsl:text>(in </xsl:text>
                                    <xsl:value-of select="$businessCurrency/@code"/>
                                    <xsl:text>)</xsl:text>
                                </th>
                            </tr>
                            
                            <tr>
                                <th style="{$headingsLineStyle} {$bold} {$left}">
                                    ***Currency***
                                </th>
                                <xsl:for-each select="$dates">
                                    <th style="{$headingsLineStyle} {$bold} {$right}">
                                        <xsl:value-of select="@_date"/>
                                    </th>
                                </xsl:for-each>
                            </tr>
                            
                            <xsl:for-each select="/*/currencies/row[not(@uidCurrency = 0)]">
                                <xsl:variable name="currency" select="."/>
                                
                                <tr>
                                    <td style="{$firstColumnStyle}">
                                        <xsl:value-of select="$currency/@code"/>
                                    </td>
                                    <xsl:for-each select="$dates">
                                        <xsl:variable name="date" select="@date"/>
                                        <xsl:variable name="exchangeRate" select="$currency/exchangeRates/row[@date = $date]"/>
                                        
                                        <td style="{$money}" >
                                            <span cellValue="{$exchangeRate/@rate}">
                                                <xsl:if test="$exchangeRate/@estimated">
                                                    <xsl:text>* </xsl:text>
                                                </xsl:if>
                                                
                                                <xsl:call-template name="formatExchRate">
                                                    <xsl:with-param name="rate" select="$exchangeRate/@rate"/>
                                                </xsl:call-template>
                                            </span>
                                        </td>
                                    </xsl:for-each>
                                </tr>
                            </xsl:for-each>
                            
                            <tr>
                                <td colspan="{count($dates) + 1}" style="{$firstColumnStyle} {$bottomBorder}"></td>
                            </tr>

                        </tbody>
                    </table>
                    
                    <xsl:if test="/*/currencies/row/exchangeRates/row[@estimated]">
                        <br />
                        <div style="{$h3Style}">
                            * ***ContainsEstimatedRates***
                        </div>
                    </xsl:if>
                    
                </div>
                
            </div>
        </div>
    </xsl:template>

</xsl:transform>

