<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <!-- report is HOURS -->
        <xsl:variable name="report" select="@report"/>
        <xsl:variable name="reportName">
            <xsl:text>***Hours Worked Report***</xsl:text>
        </xsl:variable>
        
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportName"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle"><xsl:value-of select="$reportName"/> ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Hours worked from***
                            <xsl:value-of select="@fromDate"/>
                            <xsl:text> ***to*** </xsl:text>
                            <xsl:value-of select="@toDate"/>
                        </h2>
                        
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="Hours Worked Report" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th style="{$headingsLineStyle}">
                                    </th>
                                    <xsl:for-each select="/*/workers/row">
                                        <th style="{$headingsLineStyle} {$right}">
                                            <xsl:value-of select="@workerName"/>
                                        </th>
                                    </xsl:for-each>
                                    <th style="{$headingsLineStyle} {$right}">
                                        ***Total***
                                    </th>
                                </tr>
                                
                                <xsl:for-each select="customers/row">
                                    <xsl:variable name="uidAccount" select="@uidAccount"/>
                                    
                                    <tr>
                                        <th style="{$firstColumnStyle} {$DrCrL}" >
                                            <xsl:value-of select="@accountName"/>
                                        </th>
                                        <xsl:for-each select="/*/workers/row">
                                            <xsl:variable name="uidWorker" select="@uidWorker"/>
                                            <td style="padding:5px 10px;text-align:right;" >
                                                <xsl:if test="/*/hours/row[@uidAccount=$uidAccount and @uidWorker=$uidWorker]">
                                                    <xsl:call-template name="formatHours">
                                                        <xsl:with-param name="seconds" select="/*/hours/row[@uidAccount=$uidAccount and @uidWorker=$uidWorker]/@timeWorked"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                        </xsl:for-each>
                                        <td style="{$money} {$DrCrR}" >
                                            <strong>
                                                <xsl:call-template name="formatHours">
                                                    <xsl:with-param name="seconds" select="sum(/*/hours/row[@uidAccount=$uidAccount]/@timeWorked)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </tr>
                                </xsl:for-each>
                                
                                <!-- Totals -->
                                <tr >
                                    <th style="{$firstColumnStyle} {$DrCrL} {$bottomBorder}">
                                        <strong>***Totals***</strong>
                                    </th>
                                    <xsl:for-each select="/*/workers/row">
                                        <xsl:variable name="uidWorker" select="@uidWorker"/>
                                        <td style="{$money} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatHours">
                                                    <xsl:with-param name="seconds" select="sum(/*/hours/row[@uidWorker=$uidWorker]/@timeWorked)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:for-each>
                                    <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                        <strong>
                                            <xsl:call-template name="formatHours">
                                                <xsl:with-param name="seconds" select="sum(/*/hours/row/@timeWorked)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                </tr>
                                
                            </tbody>
                        </table>
                    </div>
                </div>
                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
</xsl:transform>
