<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    <xsl:key name="cat" match="row" use="@uidAccountCategory"/>
    <xsl:key name="subcat" match="row" use="@uidAccountSubCat"/>
    
    <xsl:template match="/root">
        <xsl:variable name="numberOfMonths" select="@numberOfMonths"/>
        <xsl:variable name="showContained" select="@showContained"/>
        <xsl:variable name="showComparison" select="@showComparison"/>
        <xsl:variable name="showBudget">
            <xsl:if test="@hideBudget='N' and /*/accounts/row/budgetData/row">Y</xsl:if>
        </xsl:variable>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***Monthly Breakdown Report***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle">***Monthly Breakdown Report*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="Monthly Breakdown Report" style="{$tableStyle}">
                            <tbody>
                                <xsl:choose>
                                    <xsl:when test="$showBudget='Y'">
                                        <tr >
                                            <th colspan="2" class="headingsTop" style="{$headingsTopStyle}"></th>
                                            <th class="headingsTop headingUnderline" style="{$headingsTopStyle} {$headingUnderline} {$center}" colspan="4">***Total***</th>
                                            <th class="headingsTop headingUnderline" style="{$headingsTopStyle} {$headingUnderline} {$center}" colspan="3">***Average Per Month***</th>
                                            <xsl:for-each select="/*/months/row">
                                                <th class="headingsTop headingUnderline" style="{$headingsTopStyle} {$headingUnderline} {$center}" colspan="4">
                                                    <xsl:value-of select="@description"/>
                                                </th>
                                            </xsl:for-each>
                                        </tr>
                                        <tr >
                                            <th colspan="2" class="headingsBottom" style="{$headingsBottomStyle} {$left}">***Account***</th>
                                            <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Actual***</th>
                                            <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Budget***</th>
                                            <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Difference***</th>
                                            <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***% Budget***</th>
                                            
                                            <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Actual***</th>
                                            <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Budget***</th>
                                            <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Difference***</th>
                                            
                                            <xsl:for-each select="/*/months/row">
                                                <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Actual***</th>
                                                <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Budget***</th>
                                                <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***Difference***</th>
                                                <th class="headingsBottom" style="{$headingsBottomStyle} {$right}" >***% Budget***</th>
                                            </xsl:for-each>
                                        </tr>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <tr >
                                            <th colspan="2" style="{$headingsLineStyle} {$left}">
                                                ***Account***
                                            </th>
                                            <th style="{$headingsLineStyle} {$right}" >
                                                ***Total***
                                            </th>
                                            <th style="{$headingsLineStyle} {$right}" >
                                                ***Average***
                                            </th>
                                            
                                            <xsl:for-each select="/*/months/row">
                                                <th style="{$headingsLineStyle} {$right}" >
                                                    <xsl:value-of select="@description"/>
                                                </th>
                                            </xsl:for-each>
                                        </tr>
                                    </xsl:otherwise>
                                </xsl:choose>
                                
                                <xsl:variable name="allValueRows" select="/*/accounts/row"/>
                                
                                <xsl:for-each select="/*/accounts/row[generate-id() = generate-id(key('cat',@uidAccountCategory)[1])]">
                                    <xsl:variable name="uidAccountCategory" select="@uidAccountCategory"/>
                                    <xsl:variable name="accountCategoryID" select="@accountCategoryID"/>
                                    <xsl:variable name="categoryRows" select="$allValueRows[@uidAccountCategory=$uidAccountCategory]"/>
                                    <xsl:variable name="categoryMonthData" select="$categoryRows/monthData/row"/>
                                    <xsl:variable name="categoryBudgetData" select="$categoryRows/budgetData/row"/>
                                    
                                    <xsl:for-each select="/*/accounts/row[@uidAccountCategory=$uidAccountCategory][generate-id() = generate-id(key('subcat',@uidAccountSubCat)[1])]">
                                        <xsl:variable name="uidAccountSubCat" select="@uidAccountSubCat"/>
                                        <xsl:variable name="row" select="$allValueRows[@uidAccountSubCat=$uidAccountSubCat]"/>
                                        
                                        <xsl:if test="$row/monthData/row/@total != '0' or ($showBudget='Y' and $row/budgetData/row/@total != '0')">
                                            <tr>
                                                <td style="{$firstColumnStyle} {$DrCrL} {$catName}" colspan="2"><xsl:value-of select="@subCatDesc"/></td>
                                                <td style="{$money} {$DrCrL}" ></td>
                                                <xsl:if test="$showBudget='Y'">
                                                    <td style="{$money}" ></td>
                                                    <td style="{$money}" ></td>
                                                    <td style="{$money}" ></td>
                                                </xsl:if>
                                                <td style="{$money} {$DrCrL} {$DrCrR}" ></td>
                                                <xsl:if test="$showBudget='Y'">
                                                    <td style="{$money}" ></td>
                                                    <td style="{$money} {$DrCrR}" ></td>
                                                </xsl:if>
                                                <xsl:for-each select="/*/months/row">
                                                    <xsl:variable name="lastColStyle">
                                                        <xsl:if test="position()=last() and not($showBudget='Y')">
                                                            <xsl:value-of select="$DrCrR"/>
                                                        </xsl:if>
                                                    </xsl:variable>

                                                    <td style="{$money} {$lastColStyle}" ></td>
                                                    <xsl:if test="$showBudget='Y'">
                                                        <td style="{$money}" ></td>
                                                        <td style="{$money}" ></td>
                                                        <td style="{$money} {$DrCrR}" ></td>
                                                    </xsl:if>
                                                </xsl:for-each>
                                            </tr>
                                            
                                            <xsl:for-each select="$row[($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]">
                                                <xsl:variable name="uidAccount" select="@uidAccount"/>
                                                <xsl:variable name="monthData" select="$allValueRows[@uidAccountParent=$uidAccount or @uidAccount=$uidAccount]/monthData/row"/>
                                                <xsl:variable name="budgetData" select="$allValueRows[@uidAccountParent=$uidAccount or @uidAccount=$uidAccount]/budgetData/row"/>
                                                
                                                <xsl:if test="$monthData or ($showBudget='Y' and $budgetData)">
                                                    <tr>
                                                        <td style="{$firstColumnStyle} {$DrCrL} {$accountIndent1}" colspan="2">
                                                            <xsl:call-template name="formatAccountName">
                                                                <xsl:with-param name="row" select="."/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <td style="{$money} {$bold} {$DrCrL}" >
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="sum($monthData/@total)"/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <xsl:if test="$showBudget='Y'">
                                                            <td style="{$money}" >
                                                                <xsl:if test="$budgetData">
                                                                    <xsl:call-template name="formatCurrency">
                                                                        <xsl:with-param name="pence" select="sum($budgetData/@total)"/>
                                                                    </xsl:call-template>
                                                                </xsl:if>
                                                            </td>
                                                            <td style="{$money}" >
                                                                <xsl:if test="$budgetData">
                                                                    <xsl:call-template name="formatCurrency">
                                                                        <xsl:with-param name="pence" select="sum($monthData/@total) - sum($budgetData/@total)"/>
                                                                    </xsl:call-template>
                                                                </xsl:if>
                                                            </td>
                                                            <td style="{$money}" >
                                                                <xsl:call-template name="budgetCell">
                                                                    <xsl:with-param name="accountCategoryID" select="$accountCategoryID"/>
                                                                    <xsl:with-param name="actual" select="sum($monthData/@total)"/>
                                                                    <xsl:with-param name="budget" select="sum($budgetData/@total)"/>
                                                                </xsl:call-template>
                                                            </td>
                                                        </xsl:if>
                                                        <td style="{$money} {$DrCrL} {$DrCrR}" >
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="sum($monthData/@total) div $numberOfMonths"/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <xsl:if test="$showBudget='Y'">
                                                            <td style="{$money}" >
                                                                <xsl:if test="$budgetData">
                                                                    <xsl:call-template name="formatCurrency">
                                                                        <xsl:with-param name="pence" select="sum($budgetData/@total) div $numberOfMonths"/>
                                                                    </xsl:call-template>
                                                                </xsl:if>
                                                            </td>
                                                            <td style="{$money} {$DrCrR}" >
                                                                <xsl:if test="$budgetData">
                                                                    <xsl:call-template name="formatCurrency">
                                                                        <xsl:with-param name="pence" select="(sum($monthData/@total) - sum($budgetData/@total)) div $numberOfMonths"/>
                                                                    </xsl:call-template>
                                                                </xsl:if>
                                                            </td>
                                                        </xsl:if>
                                                        <xsl:for-each select="/*/months/row">
                                                            <xsl:variable name="monthNumber" select="@monthNumber"/>
                                                            <xsl:variable name="actual" select="sum($monthData[@monthNumber=$monthNumber]/@total)"/>
                                                            <xsl:variable name="lastColStyle">
                                                                <xsl:if test="position()=last() and not($showBudget='Y')">
                                                                    <xsl:value-of select="$DrCrR"/>
                                                                </xsl:if>
                                                            </xsl:variable>

                                                            <td style="{$money} {$lastColStyle}" >
                                                                <xsl:if test="$monthData[@monthNumber=$monthNumber] or ($showBudget='Y' and $budgetData[@monthNumber=$monthNumber])">
                                                                    <xsl:call-template name="formatCurrency">
                                                                        <xsl:with-param name="pence" select="$actual"/>
                                                                    </xsl:call-template>
                                                                </xsl:if>
                                                            </td>
                                                            <xsl:if test="$showBudget='Y'">
                                                                <xsl:variable name="budget" select="sum($budgetData[@monthNumber=$monthNumber]/@total)"/>
                                                                <td style="{$money}" >
                                                                    <xsl:if test="$monthData[@monthNumber=$monthNumber] or $budgetData[@monthNumber=$monthNumber]">
                                                                        <xsl:call-template name="formatCurrency">
                                                                            <xsl:with-param name="pence" select="$budget"/>
                                                                        </xsl:call-template>
                                                                    </xsl:if>
                                                                </td>
                                                                <td style="{$money}" >
                                                                    <xsl:if test="$monthData[@monthNumber=$monthNumber] or $budgetData[@monthNumber=$monthNumber]">
                                                                        <xsl:call-template name="formatCurrency">
                                                                            <xsl:with-param name="pence" select="$actual - $budget"/>
                                                                        </xsl:call-template>
                                                                    </xsl:if>
                                                                </td>
                                                                <td style="{$money} {$DrCrR}" >
                                                                    <xsl:call-template name="budgetCell">
                                                                        <xsl:with-param name="accountCategoryID" select="$accountCategoryID"/>
                                                                        <xsl:with-param name="actual" select="$actual"/>
                                                                        <xsl:with-param name="budget" select="$budget"/>
                                                                    </xsl:call-template>
                                                                </td>
                                                            </xsl:if>
                                                        </xsl:for-each>
                                                    </tr>
                                                </xsl:if>
                                                
                                            </xsl:for-each>
                                            
                                        </xsl:if>
                                        
                                    </xsl:for-each>
                                    
                                    <xsl:call-template name="blankLine">
                                        <xsl:with-param name="showBudget" select="$showBudget"/>
                                        <xsl:with-param name="month" select="/*/months/row"/>
                                    </xsl:call-template>

                                    <tr>
                                        <td style="{$firstColumnStyle} {$DrCrL} {$greySubTotalsMonthly}" colspan="2"><xsl:value-of select="@catDesc"/> (***total***)</td>
                                        
                                        <td style="{$money} {$bold} {$greySubTotalsMonthly} {$DrCrL}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($categoryMonthData/@total)"/>
                                            </xsl:call-template>
                                        </td>
                                        <xsl:if test="$showBudget='Y'">
                                            <td style="{$money} {$bold} {$greySubTotalsMonthly}" >
                                                <xsl:if test="$categoryBudgetData">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($categoryBudgetData/@total)"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$bold} {$greySubTotalsMonthly}" >
                                                <xsl:if test="$categoryBudgetData">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($categoryMonthData/@total) - sum($categoryBudgetData/@total)"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$bold} {$greySubTotalsMonthly}" >
                                                <xsl:if test="$categoryBudgetData">
                                                    <xsl:call-template name="budgetCell">
                                                        <xsl:with-param name="accountCategoryID" select="$accountCategoryID"/>
                                                        <xsl:with-param name="actual" select="sum($categoryMonthData/@total)"/>
                                                        <xsl:with-param name="budget" select="sum($categoryBudgetData/@total)"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                        </xsl:if>
                                        <td style="{$money} {$bold} {$greySubTotalsMonthly} {$DrCrL} {$DrCrR}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($categoryMonthData/@total) div $numberOfMonths"/>
                                            </xsl:call-template>
                                        </td>
                                        <xsl:if test="$showBudget='Y'">
                                            <td style="{$money} {$bold} {$greySubTotalsMonthly}" >
                                                <xsl:if test="$categoryBudgetData">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($categoryBudgetData/@total) div $numberOfMonths"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$bold} {$greySubTotalsMonthly} {$DrCrR}" >
                                                <xsl:if test="$categoryBudgetData">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="(sum($categoryMonthData/@total) - sum($categoryBudgetData/@total)) div $numberOfMonths"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                        </xsl:if>
                                        <xsl:for-each select="/*/months/row">
                                            <xsl:variable name="monthNumber" select="@monthNumber"/>
                                            <xsl:variable name="actual" select="sum($categoryMonthData[@monthNumber=$monthNumber]/@total)"/>
                                            <xsl:variable name="lastColStyle">
                                                <xsl:if test="position()=last() and not($showBudget='Y')">
                                                    <xsl:value-of select="$DrCrR"/>
                                                </xsl:if>
                                            </xsl:variable>

                                            <td style="{$money} {$bold} {$greySubTotalsMonthly} {$lastColStyle}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$actual"/>
                                                </xsl:call-template>
                                            </td>
                                            <xsl:if test="$showBudget='Y'">
                                                <xsl:variable name="budget" select="sum($categoryBudgetData[@monthNumber=$monthNumber]/@total)"/>
                                                <td style="{$money} {$bold} {$greySubTotalsMonthly}" >
                                                    <xsl:if test="$categoryBudgetData">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$budget"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money} {$bold} {$greySubTotalsMonthly}" >
                                                    <xsl:if test="$categoryBudgetData">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$actual - $budget"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money} {$bold} {$greySubTotalsMonthly} {$DrCrR}" >
                                                    <xsl:if test="$categoryBudgetData">
                                                        <xsl:call-template name="budgetCell">
                                                            <xsl:with-param name="accountCategoryID" select="$accountCategoryID"/>
                                                            <xsl:with-param name="actual" select="$actual"/>
                                                            <xsl:with-param name="budget" select="$budget"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                            </xsl:if>
                                        </xsl:for-each>
                                    </tr>
                                    
                                </xsl:for-each>
                                
                                <xsl:if test="@showPl">
                                    <xsl:call-template name="blankLine">
                                        <xsl:with-param name="showBudget" select="$showBudget"/>
                                    </xsl:call-template>
                                    
                                    <xsl:variable name="showPlBudget" select="/*/accounts/row[monthData/row/@total != '0'][budgetData/row]"/>
                                    <xsl:variable name="plTotalActual" select="sum($allValueRows[@accountCategoryID='INCOME']/monthData/row/@total)
                                    - sum($allValueRows[@accountCategoryID='EXPENSE']/monthData/row/@total)"/>
                                    <xsl:variable name="plTotalBudget" select="sum($allValueRows[@accountCategoryID='INCOME']/budgetData/row/@total)
                                    - sum($allValueRows[@accountCategoryID='EXPENSE']/budgetData/row/@total)"/>
                                    <tr >
                                        <td style="{$firstColumnStyle} {$DrCrL} {$bottomBorder}" colspan="2">***Profit / (Loss)***</td>
                                        <td style="{$money} {$bold} {$DrCrL} {$bottomBorder}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$plTotalActual"/>
                                            </xsl:call-template>
                                        </td>
                                        <xsl:if test="$showBudget='Y'">
                                            <td style="{$money} {$bold} {$bottomBorder}" >
                                                <xsl:if test="$showPlBudget">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$plTotalBudget"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$bold} {$bottomBorder}" >
                                                <xsl:if test="$showPlBudget">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$plTotalActual - $plTotalBudget"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$bold} {$bottomBorder}" >
                                                <xsl:if test="$showPlBudget">
                                                    <xsl:call-template name="budgetCell">
                                                        <xsl:with-param name="accountCategoryID">INCOME</xsl:with-param>
                                                        <xsl:with-param name="actual" select="$plTotalActual"/>
                                                        <xsl:with-param name="budget" select="$plTotalBudget"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                        </xsl:if>
                                        <td style="{$money} {$bold} {$DrCrL} {$DrCrR} {$bottomBorder}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$plTotalActual div $numberOfMonths"/>
                                            </xsl:call-template>
                                        </td>
                                        <xsl:if test="$showBudget='Y'">
                                            <td style="{$money} {$bold} {$bottomBorder}" >
                                                <xsl:if test="$showPlBudget">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$plTotalBudget div $numberOfMonths"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$bold} {$DrCrR} {$bottomBorder}" >
                                                <xsl:if test="$showPlBudget">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="($plTotalActual - $plTotalBudget) div $numberOfMonths"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                        </xsl:if>
                                        <xsl:for-each select="/*/months/row">
                                            <xsl:variable name="monthNumber" select="@monthNumber"/>
                                            <xsl:variable name="actual" select="sum($allValueRows[@accountCategoryID='INCOME']/monthData/row[@monthNumber=$monthNumber]/@total)
                                            - sum($allValueRows[@accountCategoryID='EXPENSE']/monthData/row[@monthNumber=$monthNumber]/@total)"/>
                                            <xsl:variable name="lastColStyle">
                                                <xsl:if test="position()=last() and not($showBudget='Y')">
                                                    <xsl:value-of select="$DrCrR"/>
                                                </xsl:if>
                                            </xsl:variable>
                                            
                                            <td style="{$money} {$bold} {$bottomBorder} {$lastColStyle}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$actual"/>
                                                </xsl:call-template>
                                            </td>
                                            <xsl:if test="$showBudget='Y'">
                                                <xsl:variable name="budget" select="sum($allValueRows[@accountCategoryID='INCOME']/budgetData/row[@monthNumber=$monthNumber]/@total)
                                                - sum($allValueRows[@accountCategoryID='EXPENSE']/budgetData/row[@monthNumber=$monthNumber]/@total)"/>
                                                <td style="{$money} {$bold} {$bottomBorder}" >
                                                    <xsl:if test="$showPlBudget">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$budget"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money} {$bold} {$bottomBorder}" >
                                                    <xsl:if test="$showPlBudget">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$actual - $budget"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money} {$bold} {$DrCrR} {$bottomBorder}" >
                                                    <xsl:if test="$showPlBudget">
                                                        <xsl:call-template name="budgetCell">
                                                            <xsl:with-param name="accountCategoryID">INCOME</xsl:with-param>
                                                            <xsl:with-param name="actual" select="$actual"/>
                                                            <xsl:with-param name="budget" select="$budget"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                            </xsl:if>
                                        </xsl:for-each>
                                    </tr>
                                </xsl:if>
                                
                            </tbody>
                        </table>
                        
                        <br />
                        <hr />
                        
                        <h1 style="{$h1Style}">***Notes***</h1>
                        
                        <p>***MonthlyBreakdownNote1***
                            <xsl:call-template name="formatNumber">
                                <xsl:with-param name="number" select="$numberOfMonths"/>
                            </xsl:call-template>
                        </p>
                        
                        <xsl:if test="/*/accounts/row/budgetData/row[@amount != @total]">
                            <p>***MonthlyBreakdownNote2***
                            </p>
                        </xsl:if>
                    </div>
                </div>
                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template name="budgetCell">
        <xsl:param name="accountCategoryID"/>
        <xsl:param name="budget"/>
        <xsl:param name="actual"/>
        <xsl:if test="not($budget='0')">
            <xsl:variable name="variancePc">
                <xsl:choose>
                    <xsl:when test="$budget &lt; 0">
                        <xsl:value-of select="($actual - $budget) div (-1 * $budget)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="($actual - $budget) div $budget"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <span cellValue="{$variancePc * 100}">
                <xsl:attribute name="style">
                    <xsl:choose>
                        <xsl:when test="($accountCategoryID='INCOME' and $variancePc &gt;= 0) or ($accountCategoryID='EXPENSE' and $variancePc &lt;= 0)">
                            <xsl:value-of select="$budgetGood"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$budgetBad"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:attribute>
                <xsl:call-template name="formatPercent">
                    <xsl:with-param name="pc" select="$variancePc"/>
                </xsl:call-template>
            </span>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="blankLine">
        <xsl:param name="showBudget"></xsl:param>
        <xsl:param name="month"></xsl:param>
        
        <tr>
            <td style="{$firstColumnStyle} {$DrCrL}" colspan="2">&#160;</td>
            <td style="{$money} {$DrCrL}" ></td>
            <xsl:if test="$showBudget='Y'">
                <td style="{$money}" ></td>
                <td style="{$money}" ></td>
                <td style="{$money}" ></td>
            </xsl:if>
            <td style="{$money} {$DrCrL} {$DrCrR}" ></td>
            <xsl:if test="$showBudget='Y'">
                <td style="{$money}" ></td>
                <td style="{$money} {$DrCrR}" ></td>
            </xsl:if>
            <xsl:for-each select="/*/months/row">
                <xsl:variable name="lastColStyle">
                    <xsl:if test="position()=last() and not($showBudget='Y')">
                        <xsl:value-of select="$DrCrR"/>
                    </xsl:if>
                </xsl:variable>

                <td style="{$money} {$lastColStyle}" ></td>
                <xsl:if test="$showBudget='Y'">
                    <td style="{$money}" ></td>
                    <td style="{$money}" ></td>
                    <td style="{$money} {$DrCrR}" ></td>
                </xsl:if>
            </xsl:for-each>
        </tr>
    </xsl:template>
    
</xsl:transform>
