<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>

    <xsl:decimal-format name="commonDF" decimal-separator="." grouping-separator="," NaN=""/>
    <xsl:decimal-format name="commonDFEuro" decimal-separator="," grouping-separator="." NaN=""/>
    
    <xsl:template name="rawCurrency">
        <xsl:param name="pence">0</xsl:param>
        <xsl:param name="uidCurrency">0</xsl:param>
        <xsl:variable name="currency" select="/*/currencies/row[@uidCurrency = $uidCurrency]"/>
        <xsl:variable name="currencyDivisor" select="$currency/@divisor"/>
        <xsl:variable name="currencySymbol" select="$currency/@symbol"/>
        <xsl:variable name="pounds" select="number($pence) div $currencyDivisor"/>
        <xsl:value-of select="$currencySymbol"/>
        <xsl:call-template name="formatNumber">
            <xsl:with-param name="number" select="$pounds"/>
            <xsl:with-param name="divisor" select="$currencyDivisor"/>
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="formatCurrency">
        <xsl:param name="pence">0</xsl:param>
        <xsl:param name="uidCurrency">0</xsl:param>
        <xsl:param name="blankIfZero"></xsl:param>
        <xsl:if test="number($pence) = $pence and not($blankIfZero = 'Y' and number($pence) = 0)">
            <xsl:variable name="currency" select="/*/currencies/row[@uidCurrency = $uidCurrency]"/>
            <xsl:variable name="currencyDivisor" select="$currency/@divisor"/>
            <xsl:variable name="currencySymbol" select="$currency/@symbol"/>
            <xsl:variable name="pounds" select="number($pence) div $currencyDivisor"/>
            <span cellValue="{$pounds}">
                <xsl:choose>
                    <xsl:when test="number($pence) &lt; 0">
                        <xsl:text>(</xsl:text>
                        <xsl:value-of select="$currencySymbol"/>
                        <xsl:call-template name="formatNumber">
                            <xsl:with-param name="number" select="-1 * $pounds"/>
                            <xsl:with-param name="divisor" select="$currencyDivisor"/>
                        </xsl:call-template>
                        <xsl:text>)</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>&#160;</xsl:text>
                        <xsl:value-of select="$currencySymbol"/>
                        <xsl:call-template name="formatNumber">
                            <xsl:with-param name="number" select="$pounds"/>
                            <xsl:with-param name="divisor" select="$currencyDivisor"/>
                        </xsl:call-template>
                    </xsl:otherwise>
                </xsl:choose>
            </span>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="formatPercent">
        <xsl:param name="pc">0</xsl:param>
        <xsl:variable name="formatCode" select="/*/@formatCode"/>
        <xsl:choose>
            <xsl:when test="$formatCode = 'commonDFEuro'">
                <xsl:value-of select="format-number($pc, '#.##0,0%', $formatCode)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="format-number($pc, '#,##0.0%', $formatCode)"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="formatExchRate">
        <xsl:param name="rate">0</xsl:param>
        <xsl:variable name="formatCode" select="/*/@formatCode"/>
        <xsl:choose>
            <xsl:when test="$formatCode = 'commonDFEuro'">
                <xsl:value-of select="format-number($rate, '#.##0,#####', $formatCode)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="format-number($rate, '#,##0.#####', $formatCode)"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="formatHours">
        <xsl:param name="seconds">0</xsl:param>
        <xsl:call-template name="formatNumber">
            <xsl:with-param name="number" select="number($seconds) div 3600"/>
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="formatNumber">
        <xsl:param name="number"></xsl:param>
        <xsl:param name="divisor">100</xsl:param>
        <xsl:param name="notrail">0</xsl:param>
        <xsl:variable name="formatCode" select="/*/@formatCode"/>
        
        <xsl:choose>
            <xsl:when test="$formatCode = 'commonDF' and $divisor = '1' and $notrail = '0'">
                <xsl:value-of select="format-number($number, '#,##0', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDF' and $divisor = '10' and $notrail = '0'">
                <xsl:value-of select="format-number($number, '#,##0.0', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDF' and $divisor = '100' and $notrail = '0'">
                <xsl:value-of select="format-number($number, '#,##0.00', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDF' and $divisor = '1000' and $notrail = '0'">
                <xsl:value-of select="format-number($number, '#,##0.000', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDFEuro' and $divisor = '1' and $notrail = '0'">
                <xsl:value-of select="format-number($number, '#.##0', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDFEuro' and $divisor = '10' and $notrail = '0'">
                <xsl:value-of select="format-number($number, '#.##0,0', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDFEuro' and $divisor = '100' and $notrail = '0'">
                <xsl:value-of select="format-number($number, '#.##0,00', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDFEuro' and $divisor = '1000' and $notrail = '0'">
                <xsl:value-of select="format-number($number, '#.##0,000', $formatCode)"/>
            </xsl:when>

            <xsl:when test="$formatCode = 'commonDF' and $divisor = '1' and $notrail = '1'">
                <xsl:value-of select="format-number($number, '#,##0', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDF' and $divisor = '10' and $notrail = '1'">
                <xsl:value-of select="format-number($number, '#,##0.#', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDF' and $divisor = '100' and $notrail = '1'">
                <xsl:value-of select="format-number($number, '#,##0.##', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDF' and $divisor = '1000' and $notrail = '1'">
                <xsl:value-of select="format-number($number, '#,##0.###', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDFEuro' and $divisor = '1' and $notrail = '1'">
                <xsl:value-of select="format-number($number, '#.##0', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDFEuro' and $divisor = '10' and $notrail = '1'">
                <xsl:value-of select="format-number($number, '#.##0,#', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDFEuro' and $divisor = '100' and $notrail = '1'">
                <xsl:value-of select="format-number($number, '#.##0,##', $formatCode)"/>
            </xsl:when>
            <xsl:when test="$formatCode = 'commonDFEuro' and $divisor = '1000' and $notrail = '1'">
                <xsl:value-of select="format-number($number, '#.##0,###', $formatCode)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="format-number($number, '#,##0.00', 'commonDF')"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
</xsl:transform>

