<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="exchangeRateGainsCommon.xslt"/>
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>

    <xsl:template match="/root">
        <xsl:variable name="showContained" select="@showContained"/>
        <xsl:variable name="showComparison" select="@showComparison"/>
        <xsl:variable name="allLeafAccounts" select="categories/row/accounts/row[@isContainer='0']"/>
        <xsl:variable name="grossProfit" select="categories/row[@isGrossProfit='1']/accounts/row[@isContainer='0']"/>
        <xsl:variable name="catWithNonZeroRows" select="categories/row[accounts/row[not(number(@total)=0 and not(@totalAccrual) and (not(comparison) or (not(@totalAccrual) and number(comparison/@total)=0)) )]]"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***Profit and Loss Report***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle">***Profit and Loss Report*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="Profit and Loss Report" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th colspan="2" class="headingsTop" style="{$headingsTopStyle}">
                                    </th>
                                    <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$headingUnderline} {$center}">
                                        <xsl:value-of select="@fromDate"/> <br/>***to*** <xsl:value-of select="@toDate"/>
                                    </th>
                                    <xsl:if test="$showComparison='Y'">
                                        <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$headingUnderline} {$center}">
                                            <xsl:value-of select="@fromDateComparison"/> <br/>***to*** <xsl:value-of select="@toDateComparison"/>
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <tr >
                                    <th colspan="2" class="headingsBottom" style="{$headingsBottomStyle} {$left}">
                                        ***Account***
                                    </th>
                                    <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                        ***Expense***
                                    </th>
                                    <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                        ***Income***
                                    </th>
                                    <xsl:if test="$showComparison='Y'">
                                        <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                            ***Expense***
                                        </th>
                                        <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                            ***Income***
                                        </th>
                                    </xsl:if>
                                </tr>

                                <!-- List all income categories -->
                                <xsl:call-template name="outputPlCategory">
                                    <xsl:with-param name="plCategoryRows" select="$catWithNonZeroRows[@isIncome='1']"/>
                                </xsl:call-template>

                                <!-- Total income -->
                                <xsl:call-template name="blankAccountLine"/>
                                <xsl:call-template name="account">
                                    <xsl:with-param name="indent">0</xsl:with-param>
                                    <xsl:with-param name="bold">Y</xsl:with-param>
                                    <xsl:with-param name="accountName">***TotalIncome***</xsl:with-param>
                                    <xsl:with-param name="total" select="sum($allLeafAccounts[@scaleBalance = '-1']/@total)"/>
                                    <xsl:with-param name="comparisonTotal">
                                        <xsl:if test="$showComparison='Y'">
                                            <xsl:value-of select="sum($allLeafAccounts[@scaleBalance = '-1']/comparison/@total)"/>
                                        </xsl:if>
                                    </xsl:with-param>
                                    <xsl:with-param name="scaleBalance">-1</xsl:with-param>
                                </xsl:call-template>

                                <xsl:call-template name="blankAccountLine"/>
                                
                                <!-- List direct expenses -->
                                <xsl:variable name="plCategoryDirectExpenses" select="$catWithNonZeroRows[@isIncome='0'][@isGrossProfit='1']"/>
                                <xsl:if test="$plCategoryDirectExpenses">
                                    <xsl:call-template name="outputPlCategory">
                                        <xsl:with-param name="plCategoryRows" select="$plCategoryDirectExpenses"/>
                                    </xsl:call-template>

                                    <!-- Gross profit (show if any direct expenses) -->
                                    <xsl:call-template name="blankAccountLine"/>
                                    
                                    <xsl:call-template name="account">
                                        <xsl:with-param name="indent">0</xsl:with-param>
                                        <xsl:with-param name="bold">Y</xsl:with-param>
                                        <xsl:with-param name="accountName">***GrossProfit***</xsl:with-param>
                                        <xsl:with-param name="total" select="sum($grossProfit/@total)"/>
                                        <xsl:with-param name="comparisonTotal">
                                            <xsl:if test="$showComparison='Y'">
                                                <xsl:value-of select="sum($grossProfit/comparison/@total)"/>
                                            </xsl:if>
                                        </xsl:with-param>
                                        <xsl:with-param name="scaleBalance">-1</xsl:with-param>
                                    </xsl:call-template>
                                </xsl:if>

                                <!-- List indirect expenses -->
                                <xsl:variable name="plCategoryIndirectExpenses" select="$catWithNonZeroRows[@isIncome='0'][@isGrossProfit='0']"/>
                                <xsl:call-template name="outputPlCategory">
                                    <xsl:with-param name="plCategoryRows" select="$plCategoryIndirectExpenses"/>
                                </xsl:call-template>

                                <!-- Total expenses -->
                                <xsl:call-template name="blankAccountLine"/>
                                <xsl:call-template name="account">
                                    <xsl:with-param name="indent">0</xsl:with-param>
                                    <xsl:with-param name="bold">Y</xsl:with-param>
                                    <xsl:with-param name="accountName">***TotalExpenses***</xsl:with-param>
                                    <xsl:with-param name="total" select="sum($allLeafAccounts[@scaleBalance = '1']/@total)"/>
                                    <xsl:with-param name="comparisonTotal">
                                        <xsl:if test="$showComparison='Y'">
                                            <xsl:value-of select="sum($allLeafAccounts[@scaleBalance = '1']/comparison/@total)"/>
                                        </xsl:if>
                                    </xsl:with-param>
                                    <xsl:with-param name="scaleBalance">1</xsl:with-param>
                                </xsl:call-template>

                                <xsl:call-template name="blankAccountLine"/>
                                <tr >
                                    <th colspan="2" style="{$firstColumnStyle} {$DrCrL} {$bottomBorder}">
                                        <strong>
                                            ***Profit / (Loss)***
                                        </strong>
                                    </th>
                                    <xsl:if test="not($showComparison='Y')">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            &#160;
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="-1 * sum($allLeafAccounts/@total)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                    <xsl:if test="$showComparison='Y'">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            &#160;
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="-1 * sum($allLeafAccounts/@total)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            &#160;
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="-1 * sum($allLeafAccounts/comparison/@total)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                </tr>
                            </tbody>
                        </table>
                        
                    </div>
                </div>
                
                <br />
                
                <xsl:if test="/*/gains/row">
                    <hr />
                    <br />
                    <xsl:call-template name="gainsLosses"/>
                </xsl:if>

                <xsl:variable name="row" select="/*/categories/row/accounts/row
                                                 [not(sum(adjustments/row/@netAllocated) = 0 and
                                                  (not(@prevAdjAmount) or @prevAdjAmount = 0) and
                                                  (not(@totalAccrual) or @totalAccrual = 0) )]"/>
                <xsl:if test="$row">
                    <hr />
                    <div style="page-break-after:always"></div>
                    <br />
                    
                    <div class="tableWrapperOuter" style="{$tableWrapperOuter}">
                        <div class="tableWrapperInner" style="{$tableWrapperInner}">
                            
                            <div>
                                <h1 style="{$h1Style}">***CashSchemeAdjustment***</h1>
                                <br/>
                                <table title="Calculation" style="{$tableStyle}">
                                    <tbody>
                                        <tr>
                                            <th style="{$headingsLineStyle} {$bold} {$left}">
                                                ***Account***
                                            </th>
                                            <th style="{$headingsLineStyle} {$bold} {$right}">
                                                ***Invoice***
                                            </th>
                                            <th style="{$headingsLineStyle} {$bold} {$right}">
                                                ***Date***
                                            </th>
                                            <th style="{$headingsLineStyle} {$bold} {$right}">
                                                ***AllocatedPc***
                                            </th>
                                            <th style="{$headingsLineStyle} {$bold} {$right}">
                                                ***Adjustments***
                                            </th>
                                            <th style="{$headingsLineStyle} {$bold} {$right}">
                                                ***Total***
                                            </th>
                                        </tr>
                                        
                                        <xsl:for-each select="$row">
                                            <xsl:variable name="totalAdjustment" select="-1 * sum(adjustments/row/@netAllocated)"/>
                                            
                                            <tr>
                                                <td style="{$firstColumnStyle} {$DrCrL} {$lineover}">
                                                    <xsl:value-of select="@accountName"/>
                                                </td>
                                                <td style="{$money} {$lineover}" >
                                                    ***B/F***
                                                </td>
                                                <td colspan="3" style="{$money} {$lineover}" >
                                                </td>
                                                <td style="{$money} {$lineover} {$DrCrR}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@scaleBalance * @prevAdjAmount"/>
                                                    </xsl:call-template>
                                                </td>
                                            </tr>
                                            
                                            <tr>
                                                <td style="{$firstColumnStyle} {$DrCrL}">
                                                </td>
                                                <td style="{$money}" >
                                                    <xsl:choose>
                                                        <xsl:when test="@accountCategoryID='INCOME'">***Sales***</xsl:when>
                                                        <xsl:when test="@accountCategoryID='EXPENSE'">***Expenses***</xsl:when>
                                                    </xsl:choose>
                                                </td>
                                                <td colspan="3" style="{$money}" >
                                                </td>
                                                <td style="{$money} {$DrCrR}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@scaleBalance * @totalAccrual"/>
                                                    </xsl:call-template>
                                                </td>
                                            </tr>
                                            
                                            <xsl:for-each select="adjustments/row">
                                                <tr>
                                                    <td style="{$firstColumnStyle} {$DrCrL}">
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:value-of select="@whatForText"/>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:value-of select="@_postingDate"/>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatPercent">
                                                            <xsl:with-param name="pc" select="@proportion"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="-1 * @netAllocated"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money} {$DrCrR}" >
                                                        <xsl:if test="position() = last()">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="$totalAdjustment"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                
                                            </xsl:for-each>
                                            
                                            <tr>
                                                <td style="{$firstColumnStyle} {$DrCrL}">
                                                </td>
                                                <td colspan="2" style="{$money} {$bold}" >
                                                </td>
                                                <td style="{$money} {$bold} {$lineover}" >
                                                    ***Total***
                                                </td>
                                                <td style="{$money} {$bold} {$lineover}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$totalAdjustment"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money} {$bold} {$lineover} {$DrCrR}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@scaleBalance * @total"/>
                                                    </xsl:call-template>
                                                </td>
                                            </tr>
                                            
                                            <tr>
                                                <td style="{$firstColumnStyle} {$DrCrL}">
                                                </td>
                                                <td colspan="4" style="{$money}" >
                                                </td>
                                                <td style="{$money} {$DrCrR}" >
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                        
                                        <tr>
                                            <td style="{$firstColumnStyle} {$DrCrL} {$bottomBorder}">
                                            </td>
                                            <td colspan="4" style="{$money} {$bottomBorder}" >
                                            </td>
                                            <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            </td>
                                        </tr>
                                        
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </xsl:if>
                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template name="outputPlCategory">
        <xsl:param name="plCategoryRows"/>

        <xsl:variable name="showContained" select="/*/@showContained"/>
        <xsl:variable name="showComparison" select="/*/@showComparison"/>
        
        <xsl:for-each select="$plCategoryRows">
            <xsl:variable name="rowNonZero" select="accounts/row[not(number(@total)=0 and not(@totalAccrual) and (not(comparison) or (not(@totalAccrual) and number(comparison/@total)=0)) )]"/>
            <xsl:variable name="row" select="$rowNonZero[($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]"/>
            <xsl:variable name="rowCount" select="count($row)"/>
            
            <xsl:if test="$rowCount &gt; 0">
                <xsl:call-template name="accountSubCatLine">
                    <xsl:with-param name="title" select="@description"/>
                </xsl:call-template>

                <xsl:for-each select="$row">
                    <xsl:call-template name="accountLine">
                        <xsl:with-param name="row" select="$row"/>
                    </xsl:call-template>
                </xsl:for-each>

                <xsl:if test="$rowCount &gt; 1">
                    <xsl:call-template name="account">
                        <xsl:with-param name="bold">Y</xsl:with-param>
                        <xsl:with-param name="accountName"><xsl:value-of select="@description"/> (***total***)</xsl:with-param>
                        <xsl:with-param name="total" select="sum(accounts/row[@isContainer='0']/@total)"/>
                        <xsl:with-param name="comparisonTotal">
                            <xsl:if test="$showComparison='Y'">
                                <xsl:value-of select="sum(accounts/row[@isContainer='0']/comparison/@total)"/>
                            </xsl:if>
                        </xsl:with-param>
                        <xsl:with-param name="scaleBalance">
                            <xsl:choose>
                                <xsl:when test="@isIncome='1'">-1</xsl:when>
                                <xsl:otherwise>1</xsl:otherwise>
                            </xsl:choose>
                        </xsl:with-param>
                    </xsl:call-template>
                </xsl:if>
            </xsl:if>
            
        </xsl:for-each>
    </xsl:template>

</xsl:transform>
