<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="showSrcAccount" select="@showSrcAccount"/>
        <xsl:variable name="addVatToBalance" select="@addVatToBalance"/>
        <xsl:variable name="scaleBalance" select="@scaleBalance"/>
        <xsl:variable name="reportTitle2">
            <xsl:choose>
                <xsl:when test="@report = 'TXBYACCOUNT'">
                    <xsl:value-of select="@accountName"/>
                    <xsl:text> (</xsl:text>
                    <xsl:value-of select="@categoryName"/>
                    <xsl:text>)</xsl:text>
                </xsl:when>
                <xsl:when test="@report = 'TXBYCATEGORY'">
                    <xsl:value-of select="@categoryName"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="reportTitle1">
            <xsl:choose>
                <xsl:when test="@report = 'TXBYACCOUNT'">
                    <xsl:text>***TransactionsByAccount***</xsl:text>
                </xsl:when>
                <xsl:when test="@report = 'TXBYCATEGORY'">
                    <xsl:text>***TransactionsByCategory***</xsl:text>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="reportTitleFull">
            <xsl:value-of select="$reportTitle1"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="$reportTitle2"/>
        </xsl:variable>
        
        <xsl:variable name="businessCurrency" select="/*/currencies/row[@uidCurrency = '0']"/>
        <xsl:variable name="currencies" select="/*/currencies/row[not(@code = $businessCurrency/@code)]"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportTitle1"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle">
                            <xsl:value-of select="$reportTitle1"/>
                            <xsl:text> ***for*** </xsl:text>
                            <xsl:value-of select="@businessName"/>
                        </h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <xsl:if test="number(@selectionCount) = 0">
                            <p>
                                <xsl:if test="@report = 'TXBYACCOUNT'">
                                    <xsl:text>***PleaseSelectAnAccount.***</xsl:text>
                                </xsl:if>
                                <xsl:if test="@report = 'TXBYCATEGORY'">
                                    <xsl:text>***PleaseSelectACategory.***</xsl:text>
                                </xsl:if>
                            </p>
                        </xsl:if>
                        
                        <xsl:if test="number(@selectionCount) &gt; 0">
                            <h2 style="{$h2Style}">
                                <xsl:value-of select="$reportTitle2"/>
                            </h2>
                            
                            <table id="mainTable" class="paddedTable" title="{$reportTitleFull}" style="{$tableStyle}">
                                <colgroup>
                                    <col style="{$DrCrL}"/>
                                    <xsl:if test="$showSrcAccount=1">
                                        <col />
                                    </xsl:if>
                                    <col />
                                    <col />
                                    <col />
                                    <col />
                                    <xsl:for-each select="/*/currencyTotals/row">
                                        <col style="{$DrCrL}"/>
                                        <col style="{$DrCrR}"/>
                                        <col style="{$DrCrR}"/>
                                    </xsl:for-each>
                                </colgroup>
                                <tbody>
                                    <xsl:if test="/*/@foreignCurrencyCount &gt; 0">
                                        <tr>
                                            <th style="{$headingsLineStyle}">
                                                <xsl:attribute name="colspan">
                                                    <xsl:choose>
                                                        <xsl:when test="$showSrcAccount=1">
                                                            6
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            5
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:attribute>
                                            </th>
                                            <xsl:for-each select="/*/currencyTotals/row">
                                                <xsl:variable name="uidCurrency" select="@uidCurrency"/>
                                                <th colspan="3" style="{$headingsLineStyle} {$center}">
                                                    <xsl:value-of select="$currencies[@uidCurrency=$uidCurrency]/@code"/>
                                                </th>
                                            </xsl:for-each>
                                        </tr>
                                    </xsl:if>
                                    
                                    <tr >
                                        <th style="{$headingsLineStyle} {$left}">
                                            ***Date***
                                        </th>
                                        <xsl:if test="$showSrcAccount=1">
                                            <th style="{$headingsLineStyle} {$left}">
                                                ***Account***
                                            </th>
                                        </xsl:if>
                                        <th style="{$headingsLineStyle} {$left}">
                                            ***Description***
                                        </th>
                                        <th style="{$headingsLineStyle} {$left}">
                                            ***Detail***
                                        </th>
                                        <th style="{$headingsLineStyle} {$left}">
                                            ***Category***
                                        </th>
                                        <th style="{$headingsLineStyle} {$left}">
                                            ***Account***
                                        </th>
                                        <xsl:for-each select="/*/currencyTotals/row">
                                            <th style="{$headingsLineStyle} {$right}">
                                                ***Debit***
                                            </th>
                                            <th style="{$headingsLineStyle} {$right}">
                                                ***Credit***
                                            </th>
                                            <th style="{$headingsLineStyle} {$right}">
                                                ***Balance***
                                            </th>
                                        </xsl:for-each>
                                    </tr>
                                    
                                    <!-- Balance Brought Forward -->
                                    <tr >
                                        <td style="{$firstColumnStyle}">
                                        </td>
                                        <xsl:if test="$showSrcAccount=1">
                                            <td></td>
                                        </xsl:if>
                                        <td></td>
                                        <td></td>
                                        <td></td>
                                        <td></td>
                                        <xsl:for-each select="/*/currencyTotals/row">
                                            <td></td>
                                            <td></td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$scaleBalance * @bfBalance"/>
                                                    <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                </xsl:call-template>
                                            </td>
                                        </xsl:for-each>
                                    </tr>
                                    
                                    <!-- List of Transactions -->
                                    <xsl:for-each select="transactions/row">
                                        <xsl:variable name="transaction" select="."/>
                                        <xsl:variable name="total" select="@amount"/>
                                        <xsl:variable name="showVatLine">
                                            <xsl:if test="$addVatToBalance = '1' and not(@vatAmount = '0' and @vatAmountCurr = '0')">
                                                <xsl:text>1</xsl:text>
                                            </xsl:if>
                                        </xsl:variable>
                                        
                                        <tr class="transactionRow" uidJournal="{@uidJournal}">
                                            <td style="{$firstColumnStyle}" >
                                                <xsl:if test="@_postingDate">
                                                    <xsl:value-of select="@_postingDate"/>
                                                </xsl:if>
                                            </td>
                                            <xsl:if test="$showSrcAccount=1">
                                                <td>
                                                    <xsl:choose>
                                                        <xsl:when test="@isVatTx">
                                                            <xsl:value-of select="@account3Name"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <xsl:value-of select="@account1Name"/>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                            </xsl:if>
                                            <td><xsl:value-of select="@whatForText"/></td>
                                            <td><xsl:value-of select="@detail"/></td>
                                            <td><xsl:value-of select="@a2subCatDesc"/></td>
                                            <td><xsl:value-of select="@account2Name"/></td>
                                            
                                            <xsl:for-each select="amounts/row">
                                                <td style="{$money}" >
                                                    <xsl:if test="@amount &gt; 0">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@amount"/>
                                                            <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money}" >
                                                    <xsl:if test="@amount &lt; 0">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="-1 * @amount"/>
                                                            <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money}" >
                                                    <xsl:if test="not($showVatLine = '1')">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$scaleBalance * @balance"/>
                                                            <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                            </xsl:for-each>
                                        </tr>
                                        
                                        <xsl:if test="$showVatLine = '1'">
                                            <tr class="transactionRow" uidJournal="{@uidJournal}">
                                                <td style="{$firstColumnStyle}" ></td>
                                                <xsl:if test="$showSrcAccount=1">
                                                    <td></td>
                                                </xsl:if>
                                                <td></td>
                                                <td></td>
                                                <td><xsl:value-of select="@a3subCatDesc"/></td>
                                                <td><xsl:value-of select="@account3Name"/></td>
                                                
                                                <xsl:for-each select="amounts/row">
                                                    <td style="{$money}" >
                                                        <xsl:if test="@vatAmount &gt; 0">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="@vatAmount"/>
                                                                <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:if test="@vatAmount &lt; 0">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="-1 * @vatAmount"/>
                                                                <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="$scaleBalance * @balance"/>
                                                            <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                        </xsl:call-template>
                                                    </td>
                                                </xsl:for-each>
                                            </tr>
                                        </xsl:if>
                                        
                                    </xsl:for-each>
                                    
                                    <!-- Totals -->
                                    <tr >
                                        <td style="{$firstColumnStyle} {$bottomBorder}">
                                            &#160;
                                        </td>
                                        <xsl:if test="$showSrcAccount=1">
                                            <td style="{$bottomBorder}"></td>
                                        </xsl:if>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$money} {$bottomBorder}">
                                            <strong>
                                                ***Total***
                                            </strong>
                                        </td>

                                        <xsl:for-each select="/*/currencyTotals/row">
                                            <td style="{$money} {$bottomBorder}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@drTotal"/>
                                                        <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money} {$bottomBorder}" >
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="@crTotal"/>
                                                        <xsl:with-param name="uidCurrency" select="@uidCurrency"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </td>
                                            <td style="{$money} {$bottomBorder}" >
                                                &#160;
                                            </td>
                                        </xsl:for-each>
                                    </tr>
                                    
                                </tbody>
                            </table>
                            
                            <br />
                            <div style="{$h3Style}">
                                <xsl:if test="not(@debitText = 'Debit')">
                                    ***Debit*** = <xsl:value-of select="@debitText"/><br />
                                </xsl:if>
                                <xsl:if test="not(@creditText = 'Credit')">
                                    ***Credit*** = <xsl:value-of select="@creditText"/><br />
                                </xsl:if>
                                <xsl:if test="not(@balanceText = 'Balance')">
                                    ***Balance*** = <xsl:value-of select="@balanceText"/><br />
                                </xsl:if>
                            </div>
                        </xsl:if>

                    </div>
                </div>
                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
</xsl:transform>
