<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="vatReturnCommon.xslt"/>
    <xsl:import href="cssStyles.xslt"/>
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="vat" select="@vatName"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***VAT Transactions***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}" class="mainTitle">***VAT Transactions*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <div>
                            
                            <xsl:if test="accounts/row[transactions/row[@uidAccount]]">
                                <div>
                                    <table id="mainTable" title="Transactions" style="{$tableStyle}" width="100%">
                                        <tbody>
                                            <tr>
                                                <td colspan="4"></td>
                                                <td width="12%"></td>
                                                <td width="12%"></td>
                                                <td width="12%"></td>
                                            </tr>
                                            
                                            <xsl:for-each select="accounts/row[transactions/row[@uidAccount]]">
                                                <xsl:sort select="@tbDisplaySequence" order="descending" data-type="number"/>
                                                <xsl:sort select="@sortLast"/>
                                                <xsl:sort select="@vatRate" order="descending" data-type="number"/>
                                                <xsl:sort select="@accountName"/>

                                                <xsl:variable name="uidAccount" select="@uidAccount"/>
                                                <tr >
                                                    <td colspan="7" style="{$h1Style} {$left}">
                                                        <xsl:value-of select="@accountName"/>
                                                    </td>
                                                </tr>
                                                <xsl:if test="@description">
                                                    <tr >
                                                        <td colspan="7">
                                                            <p><xsl:value-of select="@description"/></p>
                                                        </td>
                                                    </tr>
                                                </xsl:if>
                                                <tr >
                                                    <th style="{$headingsLineStyle} {$bold} {$left}">
                                                        ***Date***
                                                    </th>
                                                    <th style="{$headingsLineStyle} {$bold} {$left}">
                                                        ***Account***
                                                    </th>
                                                    <th style="{$headingsLineStyle} {$bold} {$left}">
                                                        ***Description***
                                                    </th>
                                                    <th style="{$headingsLineStyle} {$bold} {$left}">
                                                        ***Account***
                                                    </th>
                                                    <th style="{$headingsLineStyle} {$bold} {$right}">
                                                        ***ExVAT***
                                                    </th>
                                                    <th style="{$headingsLineStyle} {$bold} {$right}">
                                                        <xsl:if test="not($uidAccount = '0')">
                                                            ***VAT***
                                                        </xsl:if>
                                                    </th>
                                                    <th style="{$headingsLineStyle} {$bold} {$right}">
                                                        <xsl:if test="not($uidAccount = '0')">
                                                            ***Percent***
                                                        </xsl:if>
                                                    </th>
                                                </tr>

                                                <xsl:for-each select="transactions/row">
                                                    <xsl:variable name="total" select="@amount"/>
                                                    
                                                    <tr class="transactionRow" uidJournal="{@uidJournal}">
                                                        <td style="{$firstColumnStyle} {$DrCrL}">
                                                            <xsl:if test="@_postingDate">
                                                                <xsl:value-of select="@_postingDate"/>
                                                            </xsl:if>
                                                        </td>
                                                        <td style="{$descColumnStyle}"><xsl:value-of select="@account2Name"/></td>
                                                        <td style="{$descColumnStyle}"><xsl:value-of select="@whatForText"/></td>
                                                        <td style="{$descColumnStyle}"><xsl:value-of select="@account1Name"/></td>
                                                        
                                                        <td style="{$money} {$DrCrL}" >
                                                            <xsl:if test="not(number(@amountPos) = 0)">
                                                                <xsl:call-template name="formatCurrency">
                                                                    <xsl:with-param name="pence" select="@amountPos"/>
                                                                </xsl:call-template>
                                                            </xsl:if>
                                                        </td>
                                                        
                                                        <td style="{$money}" >
                                                            <xsl:if test="not($uidAccount = '0')">
                                                                <xsl:call-template name="formatCurrency">
                                                                    <xsl:with-param name="pence" select="@vatAmountPos"/>
                                                                </xsl:call-template>
                                                            </xsl:if>
                                                        </td>
                                                        <td style="{$money} {$DrCrR}" >
                                                            <xsl:if test="not($uidAccount = '0') and not(number(@amountPos) = 0)">
                                                                <xsl:call-template name="formatNumber">
                                                                    <xsl:with-param name="number" select="100 * @vatAmountPos div @amountPos"/>
                                                                </xsl:call-template>
                                                            </xsl:if>
                                                        </td>
                                                    </tr>
                                                </xsl:for-each>
                                                <tr>
                                                    <td colspan="4" style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder}">***Total***</td>
                                                    <td style="{$money} {$bold} {$DrCrL} {$bottomBorder}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum(transactions/row/@amountPos)"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money} {$bold} {$bottomBorder}" >
                                                        <xsl:if test="not($uidAccount = '0')">
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="sum(transactions/row/@vatAmountPos)"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                    <td style="{$money} {$bold} {$DrCrR} {$bottomBorder}" >
                                                        <xsl:if test="not($uidAccount = '0') and not(number(sum(transactions/row/@amountPos)) = 0)">
                                                            <xsl:call-template name="formatNumber">
                                                                <xsl:with-param name="number" select="100 * sum(transactions/row/@vatAmountPos) div sum(transactions/row/@amountPos)"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th colspan="4">&#160;
                                                    </th>
                                                </tr>
                                                
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </div>
                                <br />
                            </xsl:if>
                            
                        </div>
                    </div>
                </div>
                <xsl:call-template name="preparedOn">
                    <xsl:with-param name="message">***Prepared on***</xsl:with-param>
                </xsl:call-template>
            </body>
        </html>
    </xsl:template>
    
</xsl:transform>
