<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:import href="cssStyles.xslt"/>

    <xsl:template name="aggregatedTransactions">
        <xsl:param name="rows"/>
        <xsl:param name="title"/>
        <xsl:variable name="filteredRows" select="$rows[transactions/row or (@prevAdjAmount and number(@prevAdjAmount) != 0) or (@prevAdjVatAmount and number(@prevAdjVatAmount) != 0) or (@adjAmount and number(@adjAmount) != 0) or (@adjVatAmount and number(@adjVatAmount) != 0)]"/>
        
        <xsl:if test="$filteredRows">
            <hr/>
            <p><xsl:value-of select="$title"/></p>
            <div>
                <table title="Transactions (Aggregated)" style="{$tableStyle}" width="100%">
                    <tbody>
                        <tr>
                            <td></td>
                            <td width="12%"></td>
                            <td width="12%"></td>
                            <td width="12%"></td>
                        </tr>
                        
                        <xsl:for-each select="$filteredRows">
                            <xsl:sort select="@tbDisplaySequence" order="descending" data-type="number"/>
                            <xsl:sort select="@sortLast"/>
                            <xsl:sort select="@vatRate" order="descending" data-type="number"/>
                            <xsl:sort select="@accountName"/>
                            
                            <xsl:variable name="uidAccount" select="@uidAccount"/>
                            <tr >
                                <td colspan="4" style="{$h1Style}">
                                    <xsl:value-of select="@accountName"/>
                                </td>
                            </tr>
                            <xsl:if test="@description">
                                <tr >
                                    <td colspan="4">
                                        <p><xsl:value-of select="@description"/></p>
                                    </td>
                                </tr>
                            </xsl:if>
                            <tr >
                                <th style="{$headingsLineStyle} {$bold} {$left}">
                                    ***Account***
                                </th>
                                <th style="{$headingsLineStyle} {$bold} {$right}">
                                    ***ExVAT***
                                </th>
                                <th style="{$headingsLineStyle} {$bold} {$right}">
                                    <xsl:if test="not($uidAccount = '0')">
                                        ***VAT***
                                    </xsl:if>
                                </th>
                                <th style="{$headingsLineStyle} {$bold} {$right}">
                                    <xsl:if test="not($uidAccount = '0')">
                                        ***Percent***
                                    </xsl:if>
                                </th>
                            </tr>

                            <xsl:variable name="prevAdjAmount">
                                <xsl:choose>
                                    <xsl:when test="@prevAdjAmount">
                                        <xsl:value-of select="number(@prevAdjAmount)"/>
                                    </xsl:when>
                                    <xsl:otherwise>0</xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:variable name="prevAdjVatAmount">
                                <xsl:choose>
                                    <xsl:when test="@prevAdjVatAmount">
                                        <xsl:value-of select="number(@prevAdjVatAmount)"/>
                                    </xsl:when>
                                    <xsl:otherwise>0</xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:variable name="adjAmount">
                                <xsl:choose>
                                    <xsl:when test="@adjAmount">
                                        <xsl:value-of select="number(@adjAmount)"/>
                                    </xsl:when>
                                    <xsl:otherwise>0</xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:variable name="adjVatAmount">
                                <xsl:choose>
                                    <xsl:when test="@adjVatAmount">
                                        <xsl:value-of select="number(@adjVatAmount)"/>
                                    </xsl:when>
                                    <xsl:otherwise>0</xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:variable name="subtotalAmount" select="sum(transactions/row/@amountPos)"/>
                            <xsl:variable name="subtotalVatAmount" select="sum(transactions/row/@vatAmountPos)"/>
                            
                            <xsl:for-each select="transactions/row">
                                <xsl:sort select="@amountPos" order="descending" data-type="number"/>
                                <xsl:sort select="@accountName"/>
                                <tr>
                                    <td style="{$firstColumnStyle} {$DrCrL}">
                                        <xsl:call-template name="formatAccountName">
                                            <xsl:with-param name="row" select="."/>
                                        </xsl:call-template>
                                    </td>
                                    <td style="{$money}" >
                                        <xsl:if test="not(number(@amountPos) = 0)">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@amountPos"/>
                                            </xsl:call-template>
                                        </xsl:if>
                                    </td>
                                    <td style="{$money}" >
                                        <xsl:if test="not($uidAccount = '0')">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@vatAmountPos"/>
                                            </xsl:call-template>
                                        </xsl:if>
                                    </td>
                                    <td style="{$money} {$DrCrR}" >
                                        <xsl:if test="not($uidAccount = '0') and not(number(@amountPos) = 0)">
                                            <xsl:call-template name="formatNumber">
                                                <xsl:with-param name="number" select="100 * @vatAmountPos div @amountPos"/>
                                            </xsl:call-template>
                                        </xsl:if>
                                    </td>
                                </tr>
                            </xsl:for-each>

                            <!-- Cash scheme adjustments.
                                 Show the subtotal (sales/purchases value in this VAT account for the period)
                                 but only if there are adjustments either previously or in this period.
                             -->
                            <xsl:if test="number($prevAdjAmount) != 0 or number($prevAdjVatAmount) != 0 or number($adjAmount) != 0 or number($adjVatAmount) != 0">
                                <tr>
                                    <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder}">***Subtotal***</td>
                                    <td style="{$money} {$bold} {$bottomBorder}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$subtotalAmount"/>
                                        </xsl:call-template>
                                    </td>
                                    <td style="{$money} {$bold} {$bottomBorder}" >
                                        <xsl:if test="not($uidAccount = '0')">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$subtotalVatAmount"/>
                                            </xsl:call-template>
                                        </xsl:if>
                                    </td>
                                    <td style="{$money} {$bold} {$DrCrR} {$bottomBorder}" >
                                        <xsl:if test="not($uidAccount = '0') and not($subtotalAmount = 0)">
                                            <xsl:call-template name="formatNumber">
                                                <xsl:with-param name="number" select="100 * $subtotalVatAmount div $subtotalAmount"/>
                                            </xsl:call-template>
                                        </xsl:if>
                                    </td>
                                </tr>
                            </xsl:if>

                            <xsl:if test="number($prevAdjAmount) != 0 or number($prevAdjVatAmount) != 0">
                                <tr>
                                    <td style="{$firstColumnStyle} {$DrCrL}">
                                        ***AdjustmentsPrevPeriod***
                                    </td>
                                    <td style="{$money}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$prevAdjAmount"/>
                                        </xsl:call-template>
                                    </td>
                                    <td style="{$money}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$prevAdjVatAmount"/>
                                        </xsl:call-template>
                                    </td>
                                    <td style="{$money} {$DrCrR}" >
                                        <xsl:if test="not(number($prevAdjAmount) = 0)">
                                            <xsl:call-template name="formatNumber">
                                                <xsl:with-param name="number" select="100 * $prevAdjVatAmount div $prevAdjAmount"/>
                                            </xsl:call-template>
                                        </xsl:if>
                                    </td>
                                </tr>
                            </xsl:if>

                            <xsl:if test="number($adjAmount) != 0 or number($adjVatAmount) != 0">
                                <tr>
                                    <td style="{$firstColumnStyle} {$DrCrL}">
                                        ***AdjustmentsThisPeriod***
                                    </td>
                                    <td style="{$money}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="-1 * $adjAmount"/>
                                        </xsl:call-template>
                                    </td>
                                    <td style="{$money}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="-1 * $adjVatAmount"/>
                                        </xsl:call-template>
                                    </td>
                                    <td style="{$money} {$DrCrR}" >
                                        <xsl:if test="not(number($adjAmount) = 0)">
                                            <xsl:call-template name="formatNumber">
                                                <xsl:with-param name="number" select="100 * $adjVatAmount div $adjAmount"/>
                                            </xsl:call-template>
                                        </xsl:if>
                                    </td>
                                </tr>
                            </xsl:if>

                            <tr>
                                <xsl:variable name="totalAmount" select="$subtotalAmount + $prevAdjAmount - $adjAmount"/>
                                <xsl:variable name="totalVatAmount" select="$subtotalVatAmount + $prevAdjVatAmount - $adjVatAmount"/>
                                <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder}">***Total***</td>
                                <td style="{$money} {$bold} {$bottomBorder}" >
                                    <xsl:call-template name="formatCurrency">
                                        <xsl:with-param name="pence" select="$totalAmount"/>
                                    </xsl:call-template>
                                </td>
                                <td style="{$money} {$bold} {$bottomBorder}" >
                                    <xsl:if test="not($uidAccount = '0')">
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$totalVatAmount"/>
                                        </xsl:call-template>
                                    </xsl:if>
                                </td>
                                <td style="{$money} {$bold} {$DrCrR} {$bottomBorder}" >
                                    <xsl:if test="not($uidAccount = '0') and not($totalAmount = 0)">
                                        <xsl:call-template name="formatNumber">
                                            <xsl:with-param name="number" select="100 * $totalVatAmount div $totalAmount"/>
                                        </xsl:call-template>
                                    </xsl:if>
                                </td>
                            </tr>
                            <tr>
                                <th colspan="4">&#160;
                                </th>
                            </tr>
                            
                        </xsl:for-each>
                    </tbody>
                </table>
            </div>
            <br />
        </xsl:if>
    </xsl:template>

    <xsl:template name="aggregatedSalesOrPurchases">
        <xsl:param name="rows"/>
        <xsl:param name="scaleBalance"/>
        <xsl:param name="title"/>
        <xsl:param name="description"/>
        <xsl:if test="$rows">
            <div>
                <h1 style="{$h1Style}"><xsl:value-of select="$title"/></h1>
                <p><xsl:value-of select="$description"/></p>
                <table title="{$title}" style="{$tableStyle}" width="100%">
                    <tbody>
                        <tr >
                            <th style="{$headingsLineStyle} {$bold} {$left}">
                                ***Account***
                            </th>
                            <th style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                ***B/F***
                            </th>
                            <th style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                ***ExVAT***
                            </th>
                            <th style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                ***VAT***
                            </th>
                            <th style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                ***C/F***
                            </th>
                        </tr>
                        
                        <xsl:for-each select="$rows">
                            <xsl:sort select="@total * $scaleBalance" order="descending" data-type="number"/>
                            <xsl:sort select="@accountName"/>
                            <tr>
                                <td style="{$firstColumnStyle} {$DrCrL}">
                                    <xsl:call-template name="formatAccountName">
                                        <xsl:with-param name="row" select="."/>
                                    </xsl:call-template>
                                </td>
                                <td style="{$money}" >
                                    <xsl:call-template name="formatCurrency">
                                        <xsl:with-param name="pence" select="@totalbf * $scaleBalance"/>
                                    </xsl:call-template>
                                </td>
                                <td style="{$money}" >
                                    <xsl:call-template name="formatCurrency">
                                        <xsl:with-param name="pence" select="@total * $scaleBalance"/>
                                    </xsl:call-template>
                                </td>
                                <td style="{$money}" >
                                    <xsl:call-template name="formatCurrency">
                                        <xsl:with-param name="pence" select="@vatAmount * $scaleBalance"/>
                                    </xsl:call-template>
                                </td>
                                <td style="{$money} {$DrCrR}" >
                                    <xsl:call-template name="formatCurrency">
                                        <xsl:with-param name="pence" select="@totalcf * $scaleBalance"/>
                                    </xsl:call-template>
                                </td>
                            </tr>
                        </xsl:for-each>
                        <tr >
                            <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder}">***Total***</td>
                            <td style="{$money} {$bold} {$bottomBorder}" >
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="sum($rows/@totalbf) * $scaleBalance"/>
                                </xsl:call-template>
                            </td>
                            <td style="{$money} {$bold} {$bottomBorder}" >
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="sum($rows/@total) * $scaleBalance"/>
                                </xsl:call-template>
                            </td>
                            <td style="{$money} {$bold} {$bottomBorder}" >
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="sum($rows/@vatAmount) * $scaleBalance"/>
                                </xsl:call-template>
                            </td>
                            <td style="{$money} {$bold} {$DrCrR} {$bottomBorder}" >
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="sum($rows/@totalcf) * $scaleBalance"/>
                                </xsl:call-template>
                            </td>
                        </tr>
                        
                    </tbody>
                </table>
            </div>
            <br />
        </xsl:if>
    </xsl:template>


    <xsl:template name="cashSchemeAdjustments">
        <xsl:if test="count(/*/accounts/row/adjustments/row) &gt; 0">
            <xsl:variable name="customerAdjustmentAccounts" select="/*/accounts/row[@accountCategoryID='CUSTOMER'][adjustments]"/>
            <xsl:variable name="supplierAdjustmentAccounts" select="/*/accounts/row[@accountCategoryID='SUPPLIER'][adjustments]"/>

            <div>
                <h1 style="{$h1Style}">***VATCashSchemeAdjustment***</h1>
                <xsl:if test="$customerAdjustmentAccounts/adjustments/row">
                    <xsl:call-template name="adjustments">
                        <xsl:with-param name="type">salesInvoices</xsl:with-param>
                        <xsl:with-param name="accounts" select="$customerAdjustmentAccounts"/>
                        <xsl:with-param name="thisPeriodNet" select="/*/@adjustSalesAmount"/>
                        <xsl:with-param name="thisPeriodVat" select="/*/@adjustSalesVatAmount"/>
                        <xsl:with-param name="lastPeriodNet" select="/*/@prevPeriodSalesAdjustment"/>
                        <xsl:with-param name="lastPeriodVat" select="/*/@prevPeriodDeferredSalesVAT"/>
                    </xsl:call-template>
                </xsl:if>
                <xsl:if test="$supplierAdjustmentAccounts/adjustments/row">
                    <xsl:call-template name="adjustments">
                        <xsl:with-param name="type">purchaseInvoices</xsl:with-param>
                        <xsl:with-param name="accounts" select="$supplierAdjustmentAccounts"/>
                        <xsl:with-param name="thisPeriodNet" select="/*/@adjustPurchasesAmount"/>
                        <xsl:with-param name="thisPeriodVat" select="/*/@adjustPurchasesVatAmount"/>
                        <xsl:with-param name="lastPeriodNet" select="/*/@prevPeriodPurchasesAdjustment"/>
                        <xsl:with-param name="lastPeriodVat" select="/*/@prevPeriodDeferredPurchasesVAT"/>
                    </xsl:call-template>
                </xsl:if>
            </div>
            <br />
        </xsl:if>
    </xsl:template>

    <xsl:template name="adjustments">
        <xsl:param name="type"/>
        <xsl:param name="accounts"/>
        <xsl:param name="thisPeriodNet"/>
        <xsl:param name="thisPeriodVat"/>
        <xsl:param name="lastPeriodNet"/>
        <xsl:param name="lastPeriodVat"/>

        <table title="Cash Scheme Adjustment" style="{$tableStyle}">
            <tbody>
                <tr >
                    <th style="{$headingsLineStyle} {$bold} {$left}">
                        <xsl:if test="$type='salesInvoices'">
                            <xsl:text>***Customer***</xsl:text>
                        </xsl:if>
                        <xsl:if test="$type='purchaseInvoices'">
                            <xsl:text>***Supplier***</xsl:text>
                        </xsl:if>
                    </th>
                    <th style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***Date***
                    </th>
                    <th style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***Invoice***
                    </th>
                    <th style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***Gross***
                    </th>
                    <th style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***VAT***
                    </th>
                    <th style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***AllocatedPc***
                    </th>
                    <th style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***GrossAllocated***
                    </th>
                    <th style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                        ***VATAllocated***
                    </th>
                </tr>
                
                <xsl:for-each select="$accounts">
                    <xsl:variable name="accountName" select="@accountName"/>
                    
                    <xsl:for-each select="adjustments/row">
                        <tr>
                            <td style="{$firstColumnStyle} {$DrCrL}">
                                <xsl:value-of select="$accountName"/>
                            </td>
                            <td style="{$money}" >
                                <xsl:value-of select="@_postingDate"/>
                            </td>
                            <td style="{$money}" >
                                <xsl:value-of select="@whatForText"/>
                            </td>
                            <td style="{$money}" >
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="@grossAmount"/>
                                </xsl:call-template>
                            </td>
                            <td style="{$money}" >
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="@vatAmount"/>
                                </xsl:call-template>
                            </td>
                            <td style="{$money}" >
                                <xsl:call-template name="formatPercent">
                                    <xsl:with-param name="pc" select="@proportion"/>
                                </xsl:call-template>
                            </td>
                            <td style="{$money}" >
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="@grossAllocated"/>
                                </xsl:call-template>
                            </td>
                            <td style="{$money} {$DrCrR}" >
                                <xsl:call-template name="formatCurrency">
                                    <xsl:with-param name="pence" select="@vatAllocated"/>
                                </xsl:call-template>
                            </td>
                        </tr>
                    </xsl:for-each>
                </xsl:for-each>

                <xsl:call-template name="salesOrPurchasesTotalAdj">
                    <xsl:with-param name="thisPeriodNet" select="$thisPeriodNet"/>
                    <xsl:with-param name="thisPeriodVat" select="$thisPeriodVat"/>
                    <xsl:with-param name="lastPeriodNet" select="$lastPeriodNet"/>
                    <xsl:with-param name="lastPeriodVat" select="$lastPeriodVat"/>
                </xsl:call-template>
            </tbody>
        </table>
        <br />
    </xsl:template>
    
    <xsl:template name="salesOrPurchasesTotalAdj">
        <xsl:param name="thisPeriodNet"/>
        <xsl:param name="thisPeriodVat"/>
        <xsl:param name="lastPeriodVat"/>
        <xsl:param name="lastPeriodNet"/>
        <xsl:variable name="thisPeriodGross" select="number($thisPeriodNet) + number($thisPeriodVat)"/>
        <xsl:variable name="lastPeriodGross" select="number($lastPeriodNet) + number($lastPeriodVat)"/>
        <tr >
            <td style="{$firstColumnStyle} {$DrCrL} {$bold}">***This period***</td>
            <td style="{$money} {$bold}">***Net***</td>
            <td style="{$money} {$bold}">
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$thisPeriodNet"/>
                </xsl:call-template>
            </td>
            <td style="{$money} {$bold}" ></td>
            <td style="{$money} {$bold}" ></td>
            <td style="{$money} {$bold}" ></td>
            <td style="{$money} {$bold}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$thisPeriodGross"/>
                </xsl:call-template>
            </td>
            <td style="{$money} {$bold} {$DrCrR}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$thisPeriodVat"/>
                </xsl:call-template>
            </td>
        </tr>
        <tr >
            <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder}">***Last period***</td>
            <td style="{$money} {$bold} {$bottomBorder}" >***Net***</td>
            <td style="{$money} {$bold} {$bottomBorder}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$lastPeriodNet"/>
                </xsl:call-template>
            </td>
            <td style="{$money} {$bold} {$bottomBorder}" ></td>
            <td style="{$money} {$bold} {$bottomBorder}" ></td>
            <td style="{$money} {$bold} {$bottomBorder}" ></td>
            <td style="{$money} {$bold} {$bottomBorder} {$bottomBorder}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$lastPeriodGross"/>
                </xsl:call-template>
            </td>
            <td style="{$money} {$bold} {$DrCrR} {$bottomBorder}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$lastPeriodVat"/>
                </xsl:call-template>
            </td>
        </tr>
    </xsl:template>
    
</xsl:transform>

